import { inject, getCurrentInstance, computed, defineComponent, ref, onMounted, watch, nextTick, openBlock, createBlock, Fragment, renderList, renderSlot, mergeProps, toDisplayString, resolveComponent, withCtx, createVNode, createCommentVNode, onUnmounted, watchEffect, reactive, Teleport, resolveDynamicComponent, createTextVNode, withScopeId, pushScopeId, popScopeId, toRefs, Transition, withDirectives, vShow, withModifiers, toHandlerKey, vModelRadio, provide, onBeforeMount } from 'vue';
import TIcon from '@/components/tailwind/icon/TIcon.vue';
import TFade from '@/components/tailwind/fade/TFade.vue';
import TLoading from '@/components/tailwind/loading/TLoading.vue';
import TTriangle from '@/components/tailwind/triangle/TTriangle.vue';
import TButton from '@/components/tailwind/button/TButton.vue';
import TIcon$1 from '@/components/tailwind/TIcon.vue';

const useRenderClass = (componentName) => {
    const TSettings = inject("TSettings");
    const instance = getCurrentInstance();
    const renderClass = computed(() => (className, elementName, objectBinding = {}) => {
        const getSettings = computed(() => {
            let s = TSettings?.[componentName]?.[elementName];
            const dataDelete = instance?.attrs?.[`data-${elementName}-delete`];
            const dataAdd = instance?.attrs?.[`data-${elementName}-add`];
            if (dataDelete && typeof dataDelete === "string") {
                if (!s) {
                    s = {};
                }
                if (!s.delete) {
                    s.delete = [];
                }
                s.delete = [...s.delete, ...dataDelete.split(" ")];
            }
            if (dataAdd) {
                if (!s) {
                    s = {};
                }
                if (!s.add) {
                    s.add = "";
                }
                s.add += " " + dataAdd;
            }
            return s || null;
        });
        let result = className;
        for (const k in objectBinding) {
            if (objectBinding[k]) {
                result += " " + k + " ";
            }
        }
        const settings = getSettings.value;
        if (settings) {
            if (settings.add) {
                result += " " + settings.add;
            }
            if (settings.delete) {
                settings.delete.forEach(item => {
                    result = result.replace(item, "");
                });
            }
            if (settings.replace) {
                for (const key in settings.replace) {
                    result = result.replace(key, settings.replace[key]);
                }
            }
        }
        return result;
    });
    return { renderClass };
};

var script = defineComponent({
    name: "TAccordion",
    props: {
        items: {
            type: Array,
            default: () => {
                return [];
            }
        },
        collapse: {
            type: Boolean,
            default: () => inject("t-accordion-collapse", false)
        }
    },
    setup(props, { slots }) {
        const bindToAnimate = ref([]);
        const itemRefs = ref([]);
        const getBinding = (index, show) => {
            if (show) {
                if (!itemRefs.value || !itemRefs.value[index]) {
                    return {};
                }
                return {
                    style: `max-height: ${itemRefs.value[index].scrollHeight}px`,
                    "data-show": true
                };
            }
            else {
                return { class: "max-h-0 opacity-0", "data-show": false };
            }
        };
        const initialBinding = () => {
            props.items.forEach((item, index) => {
                bindToAnimate.value[index] = getBinding(index, item.selected);
            });
        };
        onMounted(() => {
            initialBinding();
        });
        watch(() => props.items, () => {
            nextTick(() => {
                initialBinding();
            });
        }, { deep: true });
        const toggle = index => {
            if (!props.items[index].disabled) {
                const dataShow = bindToAnimate.value[index]["data-show"];
                if (!props.collapse) {
                    bindToAnimate.value.forEach((_, index) => {
                        bindToAnimate.value[index] = getBinding(index, false);
                    });
                }
                bindToAnimate.value[index] = getBinding(index, !dataShow);
            }
        };
        const { renderClass } = useRenderClass("accordion");
        return {
            renderClass,
            hasTitleSlot: !!slots.title,
            hasTextSlot: !!slots.text,
            bindToAnimate,
            itemRefs,
            toggle
        };
    }
});

function render(_ctx, _cache, $props, $setup, $data, $options) {
  return (openBlock(true), createBlock(Fragment, null, renderList(_ctx.items, (item, index) => {
    return (openBlock(), createBlock("div", { key: index }, [
      (_ctx.hasTitleSlot)
        ? (openBlock(), createBlock("div", {
            key: 0,
            onClick: $event => (_ctx.toggle(index))
          }, [
            renderSlot(_ctx.$slots, "title", mergeProps({
              show: 
            _ctx.bindToAnimate[index] ? _ctx.bindToAnimate[index]['data-show'] : false
          
            }, item, { index: index }))
          ], 8 /* PROPS */, ["onClick"]))
        : (openBlock(), createBlock("div", {
            key: 1,
            "data-name": "accordion-title",
            class: [
          {
            [_ctx.renderClass('cursor-pointer', 'titleEnabled')]: !item.disabled,
            [_ctx.renderClass('cursor-not-allowed', 'titleDisabled')]: item.disabled
          },
          _ctx.renderClass('', 'title')
        ],
            onClick: $event => (_ctx.toggle(index))
          }, toDisplayString(item.title), 11 /* TEXT, CLASS, PROPS */, ["onClick"])),
      (_ctx.hasTextSlot)
        ? (openBlock(), createBlock("div", mergeProps({
            key: 2,
            "data-name": "accordion-text",
            class: 
          _ctx.renderClass(
            'transform transition-all overflow-hidden duration-300',
            'text'
          )
        
          }, _ctx.bindToAnimate[index], {
            ref: el => (_ctx.itemRefs[index] = el)
          }), [
            renderSlot(_ctx.$slots, "text", mergeProps({
              show: 
            _ctx.bindToAnimate[index] ? _ctx.bindToAnimate[index]['data-show'] : false
          
            }, item, { index: index }))
          ], 16 /* FULL_PROPS */))
        : (openBlock(), createBlock("div", mergeProps({
            key: 3,
            "data-name": "accordion-text",
            class: 
          _ctx.renderClass(
            'transform transition-all overflow-hidden duration-300',
            'text'
          )
        
          }, _ctx.bindToAnimate[index], {
            ref: el => (_ctx.itemRefs[index] = el)
          }), toDisplayString(item.text), 17 /* TEXT, FULL_PROPS */))
    ]))
  }), 128 /* KEYED_FRAGMENT */))
}

script.render = render;
script.__file = "src/components/tailwind/accoirdion/TAccordion.vue";

var variants;
(function (variants) {
    variants["primary"] = "primary";
    variants["success"] = "success";
    variants["danger"] = "danger";
    variants["warning"] = "warning";
    variants["white"] = "white";
    variants["secondary"] = "secondary";
})(variants || (variants = {}));
var buttonSizes;
(function (buttonSizes) {
    buttonSizes["normal"] = "normal";
    buttonSizes["small"] = "small";
    buttonSizes["large"] = "large";
})(buttonSizes || (buttonSizes = {}));
var textInputVariants;
(function (textInputVariants) {
    textInputVariants["number"] = "number";
    textInputVariants["text"] = "text";
    textInputVariants["tel"] = "tel";
})(textInputVariants || (textInputVariants = {}));
var textInputAlignments;
(function (textInputAlignments) {
    textInputAlignments["right"] = "right";
    textInputAlignments["center"] = "center";
    textInputAlignments["left"] = "left";
})(textInputAlignments || (textInputAlignments = {}));
var modifierVariants;
(function (modifierVariants) {
    modifierVariants["format"] = "format";
})(modifierVariants || (modifierVariants = {}));
var size;
(function (size) {
    size["xs"] = "xs";
    size["sm"] = "sm";
    size["md"] = "md";
    size["lg"] = "lg";
    size["full"] = "full";
})(size || (size = {}));
var normalSizes;
(function (normalSizes) {
    normalSizes["xs"] = "xs";
    normalSizes["sm"] = "sm";
    normalSizes["md"] = "md";
    normalSizes["lg"] = "lg";
})(normalSizes || (normalSizes = {}));
var positionVariant;
(function (positionVariant) {
    positionVariant["topLeft"] = "topLeft";
    positionVariant["topRight"] = "topRight";
    positionVariant["bottomLeft"] = "bottomLeft";
    positionVariant["bottomRight"] = "bottomRight";
})(positionVariant || (positionVariant = {}));
var arrowDirections;
(function (arrowDirections) {
    arrowDirections["arrow-up"] = "arrow-up";
    arrowDirections["arrow-down"] = "arrow-down";
    arrowDirections["arrow-right"] = "arrow-right";
    arrowDirections["arrow-left"] = "arrow-left";
})(arrowDirections || (arrowDirections = {}));
var delayType;
(function (delayType) {
    delayType["open"] = "open";
    delayType["close"] = "close";
    delayType["both"] = "both";
})(delayType || (delayType = {}));

var script$1 = defineComponent({
    components: { TFade, TIcon },
    emits: ["update:modelValue"],
    props: {
        icon: {
            required: false,
            default: "",
            type: String
        },
        iconClass: { type: String, default: "" },
        variant: {
            type: String,
            default: "primary",
            validator: (propValue) => {
                return !!variants[propValue];
            }
        },
        modelValue: {
            type: [Number, Boolean],
            default: 0
        },
        show: {
            type: [Number, Boolean],
            default: 0
        },
        allocateSpace: {
            type: Boolean,
            default: () => false
        }
    },
    setup(props, { emit, slots }) {
        const wrapperColor = computed(() => {
            return `bg-${props.variant}-50 text-${props.variant} border-${props.variant}-50`;
        });
        const svgColor = () => {
            return `text-${props.variant}-500`;
        };
        const closeAlert = () => {
            emit("update:modelValue", false);
        };
        const showAlert = computed(() => {
            return props.modelValue || props.show;
        });
        const { renderClass } = useRenderClass("alert");
        return {
            hasIconSlot: slots.icon,
            renderClass,
            wrapperColor,
            svgColor,
            closeAlert,
            showAlert
        };
    }
});

const _hoisted_1 = {
  key: 0,
  class: "self-start"
};
const _hoisted_2 = {
  key: 1,
  class: "self-start"
};

function render$1(_ctx, _cache, $props, $setup, $data, $options) {
  const _component_t_icon = resolveComponent("t-icon");
  const _component_t_fade = resolveComponent("t-fade");

  return (openBlock(), createBlock(_component_t_fade, {
    show: _ctx.showAlert,
    "allocate-space": _ctx.allocateSpace
  }, {
    default: withCtx(() => [
      createVNode("div", {
        "data-name": "alert-container",
        class: [
        _ctx.renderClass(
          `${_ctx.wrapperColor} my-4 shadow-sm border-r-4 rounded-sm transition-opacity duration-500`,
          'container'
        )
      ],
        role: "alert"
      }, [
        createVNode("div", {
          "data-name": "alert-innerContainer",
          class: 
          _ctx.renderClass(
            'flex items-center justify-between px-3 py-3',
            'innerContainer'
          )
        
        }, [
          createVNode("div", {
            "data-name": "alert-wrapper",
            class: _ctx.renderClass('flex items-center', 'wrapper')
          }, [
            (_ctx.hasIconSlot)
              ? (openBlock(), createBlock("div", _hoisted_1, [
                  renderSlot(_ctx.$slots, "icon")
                ]))
              : (_ctx.icon)
                ? (openBlock(), createBlock("div", _hoisted_2, [
                    createVNode(_component_t_icon, {
                      "data-name": "alert-icon",
                      class: _ctx.renderClass(_ctx.iconClass, 'icon'),
                      name: _ctx.icon
                    }, null, 8 /* PROPS */, ["class", "name"])
                  ]))
                : createCommentVNode("v-if", true),
            createVNode("div", {
              "data-name": "alert-text",
              class: _ctx.renderClass('text-sm text-right', 'text')
            }, [
              renderSlot(_ctx.$slots, "default")
            ], 2 /* CLASS */)
          ], 2 /* CLASS */),
          (!_ctx.show)
            ? (openBlock(), createBlock(_component_t_icon, {
                key: 0,
                onClick: _ctx.closeAlert,
                "data-name": "alert-close",
                class: 
              _ctx.renderClass(
                'text-3xl cursor-pointer self-start leading-8',
                'close'
              )
            ,
                name: "close"
              }, null, 8 /* PROPS */, ["onClick", "class"]))
            : createCommentVNode("v-if", true),
          createCommentVNode("      </div>")
        ], 2 /* CLASS */)
      ], 2 /* CLASS */)
    ]),
    _: 3 /* FORWARDED */
  }, 8 /* PROPS */, ["show", "allocate-space"]))
}

script$1.render = render$1;
script$1.__file = "src/components/tailwind/alert/TAlert.vue";

const useKeyDown = (callback) => {
    onMounted(() => {
        document.addEventListener("keydown", callback);
    });
    onUnmounted(() => {
        document.removeEventListener("keydown", callback);
    });
};

const useSwipeElement = (disabled = false) => {
    const state = reactive({
        xStart: 0,
        xPosition: 0,
        yStart: 0,
        yPosition: 0,
        isDropped: false,
        isTouching: false
    });
    let initialFlag = true;
    let xStart = 0;
    let xPosition = 0;
    let yStart = 0;
    let yPosition = 0;
    const onDragStart = event => {
        state.isTouching = true;
        state.isDropped = false;
        if (event.type === "touchstart") {
            event.clientX = event.touches[0].clientX;
            event.clientY = event.touches[0].clientY;
        }
        state.xPosition = event.clientX;
        state.yPosition = event.clientY;
        state.xStart = event.clientX;
        state.yStart = event.clientY;
        if (initialFlag) {
            initialFlag = false;
            xPosition = event.clientX;
            yPosition = event.clientY;
            xStart = event.clientX;
            yStart = event.clientY;
        }
    };
    const reset = () => {
        state.xPosition = xPosition;
        state.yPosition = yPosition;
        state.xStart = xStart;
        state.yStart = yStart;
    };
    const resize = () => {
        initialFlag = true;
    };
    onMounted(() => {
        window.addEventListener("resize", resize);
    });
    onUnmounted(() => {
        window.removeEventListener("resize", resize);
    });
    const onDragging = event => {
        if (event.type === "touchmove") {
            event.clientX = event.touches[0].clientX;
            event.clientY = event.touches[0].clientY;
        }
        state.xPosition = event.clientX;
        state.yPosition = event.clientY;
    };
    const onDragEnd = () => {
        state.isTouching = false;
        state.isDropped = true;
        if (typeof window !== "undefined") {
            document.removeEventListener("mousemove", onDragging);
            document.removeEventListener("touchmove", onDragging);
            document.removeEventListener("mouseup", onDragEnd);
            document.removeEventListener("touchend", onDragEnd);
            document.removeEventListener("contextmenu", onDragEnd);
        }
    };
    const onButtonDown = event => {
        if (disabled)
            return;
        event.preventDefault();
        onDragStart(event);
        if (typeof window !== "undefined") {
            document.addEventListener("mousemove", onDragging);
            document.addEventListener("touchmove", onDragging);
            document.addEventListener("mouseup", onDragEnd);
            document.addEventListener("touchend", onDragEnd);
            document.addEventListener("contextmenu", onDragEnd);
        }
    };
    const yDiff = computed(() => state.yPosition - state.yStart);
    const xDiff = computed(() => state.xPosition - state.xStart);
    // watchEffect(() => {
    //   console.log("YYYYYYYYYYYYY");
    //   console.log("yDiff is : ", yDiff.value);
    //   console.log("yStart : ", state.yStart);
    //   console.log("yPosition : ", state.yPosition);
    //
    //   console.log("XXXXXXXXXXXXX");
    //   console.log("xDiff is : ", xDiff.value);
    //   console.log("xStart : ", state.xStart);
    //   console.log("xPosition : ", state.xPosition);
    // });
    return {
        bind: {
            onMousedown: onButtonDown,
            onTouchstart: onButtonDown
        },
        state,
        xDiff,
        yDiff,
        reset
    };
};
const useSwipeDownToClose = (close, threshold = 80, max = 180) => {
    const { bind: swipeEvents, yDiff, state, reset } = useSwipeElement();
    watch(() => state.isDropped, () => {
        if (yDiff.value > threshold) {
            close();
        }
        reset();
    });
    const swipeY = computed(() => {
        if (yDiff.value > 0) {
            return yDiff.value > max ? max : yDiff.value;
        }
        else {
            return 0;
        }
    });
    watchEffect(() => {
        if (yDiff.value >= max) {
            close();
        }
    });
    return { swipeEvents, swipeY, isTouching: computed(() => state.isTouching) };
};

var script$2 = defineComponent({
    name: "TBottomSheet",
    components: { TFade },
    emits: {
        "update:modelValue"(value) {
            return typeof value === "number" || typeof value === "boolean";
        }
    },
    props: {
        modelValue: {
            type: [Number, Boolean],
            default: 0
        },
        rounded: {
            type: Boolean,
            default: () => inject("t-bottom-sheet-rounded", true)
        },
        title: {
            type: String,
            default: ""
        },
        titleTag: {
            type: String,
            default: () => inject("t-bottom-sheet-titleTag", "h4")
        },
        teleportTo: {
            type: String,
            default: () => inject("t-bottom-sheet-teleportTo", undefined)
        },
        hasCloseButton: {
            type: Boolean,
            default: () => inject("t-bottom-sheet-hasCloseButton", true)
        },
        maxSize: {
            type: String,
            default: () => inject("t-bottom-sheet-maxSize", "md"),
            validator: (propValue) => {
                return !!size[propValue];
            }
        },
        closeCallback: {
            type: Function,
            default: () => {
                return () => true;
            }
        },
        full: {
            type: Boolean,
            default: () => inject("t-bottom-sheet-full", false)
        },
        eager: {
            type: Boolean,
            default: () => inject("t-bottom-sheet-eager", false)
        },
        backDrop: {
            type: Boolean,
            default: () => inject("t-bottom-sheet-backDrop", true)
        }
    },
    setup(props, { emit, slots }) {
        const close = () => {
            props.closeCallback() && emit("update:modelValue", false);
        };
        const onEscape = (e) => {
            if (e.key === "Esc" || e.key === "Escape") {
                close();
            }
        };
        useKeyDown(onEscape);
        const isTeleportDisable = computed(() => {
            return props.teleportTo === undefined;
        });
        const showTitle = computed(() => {
            return props.title && !slots.title;
        });
        const showCloseButton = computed(() => {
            return props.hasCloseButton && !slots.closeButton;
        });
        const showHeader = computed(() => {
            return (props.hasCloseButton ||
                props.title ||
                !!slots.closeButton ||
                !!slots.title);
        });
        const maxHeight = computed(() => {
            switch (props.maxSize) {
                case size.xs:
                    return { class: "max-h-1/4", variable: "25vh" };
                case size.sm:
                    return { class: "max-h-1/2", variable: "50vh" };
                case size.md:
                    return { class: "max-h-3/4", variable: "75vh" };
                case size.lg:
                    return { class: "max-h-9/10", variable: "90vh" };
                case size.full:
                    return { class: "max-h-full", variable: "100vh" };
            }
            return { class: "", variable: "" };
        });
        const { isTouching, swipeY, swipeEvents } = useSwipeDownToClose(close);
        const { renderClass } = useRenderClass("bottomSheet");
        return {
            renderClass,
            isTouching,
            swipeY,
            swipeEvents,
            maxHeight,
            close,
            showHeader,
            showCloseButton,
            showTitle,
            isTeleportDisable,
            clickedItem: () => {
                alert("item clicked");
            }
        };
    }
});

const _withId = /*#__PURE__*/withScopeId("data-v-50dd8b9c");

const render$2 = /*#__PURE__*/_withId((_ctx, _cache, $props, $setup, $data, $options) => {
  const _component_t_fade = resolveComponent("t-fade");

  return (openBlock(), createBlock(Teleport, {
    to: _ctx.teleportTo,
    disabled: _ctx.isTeleportDisable
  }, [
    (_ctx.backDrop)
      ? (openBlock(), createBlock(_component_t_fade, {
          key: 0,
          show: _ctx.modelValue,
          "allocate-space": false,
          "opacity-class": "opacity-50",
          class: "relative z-30"
        }, {
          default: _withId(({className}) => [
            createVNode("div", {
              "data-name": "bottomSheet-backDrop",
              class: [
              // { hidden: !modelValue },
              className,
              _ctx.renderClass('fixed z-20 top-0 bg-gray-900', 'backDrop')
            ],
              onClick: _cache[1] || (_cache[1] = (...args) => (_ctx.close && _ctx.close(...args)))
            }, null, 2 /* CLASS */)
          ]),
          _: 1 /* STABLE */
        }, 8 /* PROPS */, ["show"]))
      : createCommentVNode("v-if", true),
    createVNode("div", {
      "data-name": "bottomSheet-container",
      class: [
        _ctx.renderClass(
          'rounded-t-md fixed z-30 w-max max-w-full right-1/2 translate-x-1/2 bottom-0 bg-white transform',
          'container'
        ),
        {
          'translate-y-full': !_ctx.modelValue,
          'duration-300': !_ctx.isTouching || !_ctx.modelValue,
          'rounded-t-md': _ctx.rounded
        },
        _ctx.maxHeight.class,
        _ctx.$attrs.class
      ],
      style: [_ctx.modelValue ? { '--tw-translate-y': _ctx.swipeY + 'px' } : {}]
    }, [
      createVNode("div", mergeProps({
        "data-name": "bottomSheet-swiperContainer",
        class: [
          {
            [_ctx.renderClass(
              'absolute right-1/2 transform translate-x-1/2',
              'swiperContainer'
            )]: _ctx.showHeader
          },
          _ctx.renderClass('py-2', 'swiperContainer')
        ]
      }, _ctx.swipeEvents), [
        createVNode("div", {
          "data-name": "bottomSheet-swiper",
          class: 
            _ctx.renderClass(
              'bg-gray-300 mx-auto rounded-full h-1.5 w-20 cursor-pointer',
              'swiper'
            )
          
        }, null, 2 /* CLASS */)
      ], 16 /* FULL_PROPS */),
      (_ctx.showHeader)
        ? (openBlock(), createBlock("div", mergeProps({ key: 0 }, _ctx.swipeEvents, {
            "data-name": "bottomSheet-header",
            class: 
          _ctx.renderClass(
            'px-4 h-14 rounded-inherit top-0 py-4 leading-none flex justify-between items-center font-medium text-sm bg-gray-100 border-b select-none',
            'header'
          )
        
          }), [
            createVNode("div", null, [
              (_ctx.showTitle)
                ? (openBlock(), createBlock(resolveDynamicComponent(_ctx.titleTag), {
                    key: 0,
                    class: _ctx.renderClass('', 'title'),
                    "data-name": "bottomSheet-title"
                  }, {
                    default: _withId(() => [
                      createTextVNode(toDisplayString(_ctx.title), 1 /* TEXT */)
                    ]),
                    _: 1 /* STABLE */
                  }, 8 /* PROPS */, ["class"]))
                : renderSlot(_ctx.$slots, "title", { key: 1 })
            ]),
            (_ctx.showCloseButton)
              ? (openBlock(), createBlock("div", {
                  key: 0,
                  onClick: _cache[2] || (_cache[2] = (...args) => (_ctx.close && _ctx.close(...args))),
                  "data-name": "bottomSheet-close",
                  class: 
            _ctx.renderClass('text-2xl hover:text-gray-600 cursor-pointer', 'close')
          
                }, " × ", 2 /* CLASS */))
              : renderSlot(_ctx.$slots, "closeButton", {
                  key: 1,
                  onClick: _ctx.close
                })
          ], 16 /* FULL_PROPS */))
        : createCommentVNode("v-if", true),
      createVNode("div", {
        "data-name": "bottomSheet-contentContainer",
        class: [
          { 'bottom-sheet-height': _ctx.showHeader },
          _ctx.renderClass(
            'overflow-y-auto scrollbar-sm p-4 bottom-sheet-content-container',
            'contentContainer'
          )
        ],
        style: { '--max-height': _ctx.maxHeight.variable }
      }, [
        renderSlot(_ctx.$slots, "default")
      ], 6 /* CLASS, STYLE */)
    ], 6 /* CLASS, STYLE */),
    createCommentVNode("    </div>")
  ], 8 /* PROPS */, ["to", "disabled"]))
});

script$2.render = render$2;
script$2.__scopeId = "data-v-50dd8b9c";
script$2.__file = "src/components/tailwind/bottomSheet/TBottomSheet.vue";

var script$3 = defineComponent({
    props: {
        nuxt: {
            type: Boolean,
            required: false,
            default: false,
        },
        items: {
            required: true,
            type: Array,
            default: () => {
                return [];
            },
        },
    },
    setup(props, { slots }) {
        const linkType = computed(() => {
            if (!props.nuxt) {
                return "router-link";
            }
            return "nuxt-link";
        });
        const { renderClass } = useRenderClass("breadcrumb");
        return {
            linkType,
            hasDefaultSlot: !!slots.default,
            renderClass,
        };
    },
});

function render$3(_ctx, _cache, $props, $setup, $data, $options) {
  return (openBlock(), createBlock("ol", {
    "data-name": "breadcrumb-container",
    class: _ctx.renderClass('flex text-gray-500', 'container')
  }, [
    (openBlock(true), createBlock(Fragment, null, renderList(_ctx.items, (item, index) => {
      return (openBlock(), createBlock(Fragment, { key: item }, [
        createVNode("li", {
          class: ["px-2", _ctx.renderClass(item.active ? 'text-indigo-600' : '', 'active')],
          "data-name": "breadcrumb-active"
        }, [
          renderSlot(_ctx.$slots, "beforeLink", { item, index }),
          renderSlot(_ctx.$slots, "default", { item, index }),
          (!_ctx.hasDefaultSlot)
            ? (openBlock(), createBlock(resolveDynamicComponent(_ctx.linkType), {
                key: 0,
                "data-name": "breadcrumb-link",
                class: [
              _ctx.renderClass(!item.active ? 'hover:underline' : '', 'link'),
              { 'cursor-default': item.active },
            ],
                to: item.url
              }, {
                default: withCtx(() => [
                  createTextVNode(toDisplayString(item.text), 1 /* TEXT */)
                ]),
                _: 2 /* DYNAMIC */
              }, 1032 /* PROPS, DYNAMIC_SLOTS */, ["class", "to"]))
            : createCommentVNode("v-if", true),
          renderSlot(_ctx.$slots, "afterLink", { item, index })
        ], 2 /* CLASS */),
        (index + 1 < _ctx.items.length)
          ? (openBlock(), createBlock("li", {
              key: 0,
              "data-name": "breadcrumb-slash",
              class: _ctx.renderClass('text-gray-500 select-none', 'slash')
            }, " / ", 2 /* CLASS */))
          : createCommentVNode("v-if", true)
      ], 64 /* STABLE_FRAGMENT */))
    }), 128 /* KEYED_FRAGMENT */))
  ], 2 /* CLASS */))
}

script$3.render = render$3;
script$3.__file = "src/components/tailwind/breadcrumb/TBreadcrumb.vue";

var script$4 = defineComponent({
    name: "TButton",
    props: {
        rounded: {
            type: Boolean,
            default: false,
        },
        fab: {
            type: Boolean,
            default: false,
        },
        variant: {
            type: String,
            default: "primary",
            validator: (propValue) => {
                return !!variants[propValue];
            },
        },
        size: {
            type: String,
            default: "normal",
            validator: (propValue) => {
                return !!buttonSizes[propValue];
            },
        },
        color: {
            type: String,
            default: "",
        },
        icon: {
            type: String,
            default: "",
        },
        disabled: {
            type: Boolean,
            default: false,
        },
        outline: {
            type: Boolean,
            default: false,
        },
        ripple: {
            type: Boolean,
            default: false,
        },
        to: {
            type: String,
            required: false,
            default: "",
        },
        nuxt: {
            required: false,
            type: Boolean,
            default: false,
        },
        full: {
            type: Boolean,
            default: false,
            required: false,
        },
        loading: {
            type: Boolean,
            default: false,
            required: false,
        },
        loadingProps: {
            type: Object,
            default: () => ({}),
        },
    },
    components: {
        AppIcon: TIcon,
        TLoading,
    },
    setup(props, { slots }) {
        const variantClasses = computed(() => {
            const baseClass = " hover:opacity-80 transition hover:shadow-md text-white disabled:opacity-50";
            const variantClass = `bg-${props.variant} hover:bg-${props.variant}`;
            const outlineVariantClass = `bg-white border-${props.variant}-50 hover:bg-${props.variant}-50`;
            const outlineBaseClass = " transition border hover:shadow-md text-dark hover:opacity-80 disabled:opacity-50";
            let size = " ";
            let height;
            let width;
            switch (props.size) {
                case buttonSizes.small:
                    height = "h-7";
                    width = "w-7";
                    break;
                case buttonSizes.large:
                    height = "h-11";
                    width = "w-11";
                    break;
                default:
                    height = "h-9";
                    width = "w-9";
                    break;
            }
            size += height + " ";
            if (props.fab) {
                size += width;
            }
            return ((props.outline
                ? (props.color || outlineVariantClass) + outlineBaseClass
                : (props.color || variantClass) + baseClass) + size);
        });
        const loadingBindingProps = {
            variant: props.outline ? props.variant : "white",
            ...props.loadingProps,
        };
        const wrapperComponent = computed(() => {
            if (!props.to) {
                return "button";
            }
            if (props.nuxt) {
                return "nuxt-link";
            }
            return "router-link";
        });
        const { renderClass } = useRenderClass("button");
        const isDisabled = computed(() => {
            return props.loading || props.disabled;
        });
        return {
            renderClass,
            variantClasses,
            loadingBindingProps,
            hasLoadingSlot: !!slots.loading,
            wrapperComponent,
            isDisabled,
        };
    },
});

function render$4(_ctx, _cache, $props, $setup, $data, $options) {
  const _component_app_icon = resolveComponent("app-icon");
  const _component_t_loading = resolveComponent("t-loading");

  return (openBlock(), createBlock(Fragment, null, [
    createCommentVNode(" This is an example component "),
    (openBlock(), createBlock(resolveDynamicComponent(_ctx.wrapperComponent), mergeProps({
      to: _ctx.to,
      disabled: _ctx.disabled,
      "data-name": "button-container",
      class: [
      _ctx.renderClass(
        `${_ctx.variantClasses} flex justify-center items-center px-4 py-2 shadow relative rounded-sm border-1 focus:outline-none`,
        'container',
        {
          'rounded-full': _ctx.rounded,
          ripple: _ctx.ripple && !_ctx.isDisabled,
          'w-full': _ctx.full,
          'min-w-14': !_ctx.fab
        }
      ),
    ]
    }, _ctx.$attrs), {
      default: withCtx(() => [
        createVNode(_component_app_icon, {
          name: _ctx.icon,
          "data-name": "button-icon",
          class: [
        _ctx.renderClass('', 'icon', {
          'opacity-0': _ctx.loading,
          'pl-2': !_ctx.fab
        }),
      ]
        }, null, 8 /* PROPS */, ["name", "class"]),
        createVNode("span", {
          class: {
        'opacity-0': _ctx.loading,
      }
        }, [
          renderSlot(_ctx.$slots, "default")
        ], 2 /* CLASS */),
        (_ctx.loading)
          ? (openBlock(), createBlock("span", {
              key: 0,
              "data-name": "button-loadingContainer",
              class: {
        [_ctx.renderClass(
          'absolute transform top-1/2 -translate-y-1/2',
          'loadingContainer'
        )]: _ctx.loading,
      }
            }, [
              (_ctx.hasLoadingSlot)
                ? renderSlot(_ctx.$slots, "loading", mergeProps({ key: 0 }, _ctx.loadingProps))
                : (openBlock(), createBlock(_component_t_loading, mergeProps({
                    key: 1,
                    "data-name": "button-loading",
                    class: _ctx.renderClass('', 'loading')
                  }, _ctx.loadingBindingProps, { size: "sm" }), null, 16 /* FULL_PROPS */, ["class"]))
            ], 2 /* CLASS */))
          : createCommentVNode("v-if", true)
      ]),
      _: 3 /* FORWARDED */
    }, 16 /* FULL_PROPS */, ["to", "disabled", "class"]))
  ], 2112 /* STABLE_FRAGMENT, DEV_ROOT_FRAGMENT */))
}

script$4.render = render$4;
script$4.__file = "src/components/tailwind/button/TButton.vue";

var script$5 = defineComponent({
    props: {
        title: {
            type: String,
            default: ""
        },
        description: {
            type: String,
            default: ""
        }
    },
    setup() {
        const { renderClass } = useRenderClass("card");
        return { renderClass };
    }
});

function render$5(_ctx, _cache, $props, $setup, $data, $options) {
  return (openBlock(), createBlock("div", {
    "data-name": "card-container",
    class: 
      _ctx.renderClass('shadow-md border border-gray-100 text-right', 'container')
    
  }, [
    (_ctx.title)
      ? (openBlock(), createBlock("div", {
          key: 0,
          "data-name": "card-title",
          class: _ctx.renderClass('p-2 sm:p-4 font-bold', 'title')
        }, toDisplayString(_ctx.title), 3 /* TEXT, CLASS */))
      : createCommentVNode("v-if", true),
    (_ctx.description)
      ? (openBlock(), createBlock("div", {
          key: 1,
          "data-name": "card-description",
          class: _ctx.renderClass('p-2 sm:p-4', 'description')
        }, toDisplayString(_ctx.description), 3 /* TEXT, CLASS */))
      : createCommentVNode("v-if", true),
    renderSlot(_ctx.$slots, "default")
  ], 2 /* CLASS */))
}

script$5.render = render$5;
script$5.__file = "src/components/tailwind/card/TCard.vue";

var SwitchAndCheckboxProps = (isCheckbox = true) => {
    const component = isCheckbox ? "t-checkbox" : "t-switch";
    return {
        modelValue: {
            default: "",
            type: [Array, String, Number, Boolean, Object]
        },
        value: {
            type: [Array, String, Number, Boolean, Object],
            default: () => undefined
        },
        label: { type: String, default: "" },
        trueValue: {
            type: [Array, String, Number, Boolean, Object],
            default: () => inject(`${component}-trueValue`, 1)
        },
        falseValue: {
            type: [Array, String, Number, Boolean, Object],
            default: () => inject(`${component}-falseValue`, 0)
        },
        variant: {
            type: String,
            default: () => inject(`${component}-variant`, "primary"),
            validator: (propValue) => {
                // eslint-disable-next-line @typescript-eslint/ban-ts-ignore
                // @ts-ignore
                return !!variants[propValue];
            }
        },
        disabled: {
            type: Boolean,
            default: () => false
        }
    };
};

const useSwitchAndCheckbox = (props, { emit }) => {
    const compare = (item1, item2) => {
        if (typeof item1 === "object" && typeof item2 === "object") {
            return JSON.stringify(item1) === JSON.stringify(item2);
        }
        return item1 === item2;
    };
    const isChecked = computed(() => {
        if (Array.isArray(props.modelValue)) {
            return props.modelValue.some(item => compare(item, props.value));
        }
        return compare(props.modelValue, props.trueValue);
    });
    const updateInput = e => {
        if (!props.disabled) {
            const isActive = e?.target?.checked ?? !isChecked.value;
            if (Array.isArray(props.modelValue)) {
                const newValue = [...props.modelValue];
                if (isActive) {
                    newValue.push(props.value);
                }
                else {
                    newValue.splice(newValue.findIndex(item => compare(item, props.value)), 1);
                }
                emit("update:modelValue", newValue);
            }
            else {
                emit("update:modelValue", isActive ? props.trueValue : props.falseValue);
            }
        }
    };
    return { isChecked, updateInput };
};

var script$6 = defineComponent({
    props: {
        ...SwitchAndCheckboxProps(),
        activeClass: {
            type: String,
            default: () => inject("t-checkbox-activeClass", "")
        },
        inActiveClass: { type: String, default: "" },
        hideInput: {
            type: Boolean,
            default: () => false
        }
    },
    inheritAttrs: false,
    emits: ["update:modelValue"],
    setup(props, context) {
        onMounted(() => {
            if (Array.isArray(props.modelValue) && props.value === undefined) {
                console.error("TCheckboxError: v-model is Array but value is undefined you should pass a value");
            }
        });
        const { isChecked, updateInput } = useSwitchAndCheckbox(props, context);
        const { renderClass } = useRenderClass("checkbox");
        return { isChecked, updateInput, renderClass };
    }
});

const _withId$1 = /*#__PURE__*/withScopeId("data-v-3e927dbc");

pushScopeId("data-v-3e927dbc");
const _hoisted_1$1 = /*#__PURE__*/createVNode("svg", {
  class: "text-white fill-current hidden w-4 h-4 pointer-events-none",
  viewBox: "0 0 20 20"
}, [
  /*#__PURE__*/createVNode("path", { d: "M0 11l2-2 5 5L18 3l2 2L7 18z" })
], -1 /* HOISTED */);
popScopeId();

const render$6 = /*#__PURE__*/_withId$1((_ctx, _cache, $props, $setup, $data, $options) => {
  return (openBlock(), createBlock("label", {
    "data-name": "checkbox-container",
    class: [
      _ctx.renderClass('flex justify-start items-start', 'container'),
      _ctx.$attrs.class,
      {
        'cursor-pointer': !_ctx.disabled,
        [_ctx.activeClass]: _ctx.isChecked,
        [_ctx.inActiveClass]: !_ctx.isChecked
      }
    ]
  }, [
    createVNode("span", {
      "data-name": "checkbox-inputContainer",
      class: [
        {
          [`bg-${_ctx.variant} border-${_ctx.variant}`]: _ctx.isChecked && !_ctx.hideInput,
          'bg-white border-gray-400': !_ctx.isChecked && !_ctx.hideInput
        },
        _ctx.hideInput ? 'w-0 h-0' : 'w-6 h-6 border-2 mr-2',
        _ctx.renderClass(
          'rounded-xs flex flex-shrink-0 justify-center items-center',
          'inputContainer'
        )
      ]
    }, [
      createVNode("input", mergeProps({
        type: "checkbox",
        class: ["opacity-0 absolute", { 'cursor-pointer': !_ctx.disabled }]
      }, _ctx.$attrs, {
        disabled: _ctx.disabled,
        checked: _ctx.isChecked,
        value: _ctx.value,
        onChange: _cache[1] || (_cache[1] = (...args) => (_ctx.updateInput && _ctx.updateInput(...args)))
      }), null, 16 /* FULL_PROPS */, ["disabled", "checked", "value"]),
      _hoisted_1$1
    ], 2 /* CLASS */),
    (_ctx.label)
      ? (openBlock(), createBlock("span", {
          key: 0,
          "data-name": "checkbox-label",
          class: [{ 'text-gray-500': _ctx.disabled }, _ctx.renderClass('mr-2', 'label')]
        }, toDisplayString(_ctx.label), 3 /* TEXT, CLASS */))
      : createCommentVNode("v-if", true),
    renderSlot(_ctx.$slots, "label", {
      isChecked: _ctx.isChecked,
      disabled: _ctx.disabled
    })
  ], 2 /* CLASS */))
});

script$6.render = render$6;
script$6.__scopeId = "data-v-3e927dbc";
script$6.__file = "src/components/tailwind/checkbox/TCheckbox.vue";

const useMaxWidth = maxSize => computed(() => {
    switch (maxSize) {
        case size.xs:
            return "max-w-1/4";
        case size.sm:
            return "max-w-1/2";
        case size.md:
            return "max-w-3/4";
        case size.lg:
            return "max-w-9/10";
        case size.full:
            return "max-w-full";
    }
    return "";
});

var script$7 = defineComponent({
    name: "TDrawer",
    components: { TFade },
    emits: {
        "update:modelValue"(value) {
            return typeof value === "number" || typeof value === "boolean";
        }
    },
    props: {
        modelValue: {
            type: [Number, Boolean],
            default: 0
        },
        rounded: {
            type: Boolean,
            default: () => inject("t-drawer-rounded", true)
        },
        title: {
            type: String,
            default: ""
        },
        titleTag: {
            type: String,
            default: () => inject("t-drawer-titleTag", "h4")
        },
        teleportTo: {
            type: String,
            default: () => inject("t-drawer-teleportTo", undefined)
        },
        hasCloseButton: {
            type: Boolean,
            default: () => inject("t-drawer-hasCloseButton", true)
        },
        maxSize: {
            type: String,
            default: () => inject("t-drawer-maxSize", "full"),
            validator: (propValue) => {
                return !!size[propValue];
            }
        },
        closeCallback: {
            type: Function,
            default: () => {
                return () => true;
            }
        },
        full: {
            type: Boolean,
            default: () => inject("t-drawer-full", false)
        },
        left: {
            type: Boolean,
            default: () => inject("t-drawer-left", false)
        },
        eager: {
            type: Boolean,
            default: () => inject("t-drawer-eager", false)
        },
        backDrop: {
            type: Boolean,
            default: () => inject("t-drawer-backDrop", true)
        }
    },
    setup(props, { emit, slots }) {
        const close = () => {
            props.closeCallback() && emit("update:modelValue", false);
        };
        const onEscape = (e) => {
            if (e.key === "Esc" || e.key === "Escape") {
                close();
            }
        };
        useKeyDown(onEscape);
        const isTeleportDisable = computed(() => {
            return props.teleportTo === undefined;
        });
        const showTitle = computed(() => {
            return props.title && !slots.title;
        });
        const showCloseButton = computed(() => {
            return props.hasCloseButton && !slots.closeButton;
        });
        const showHeader = computed(() => {
            return (props.hasCloseButton ||
                props.title ||
                !!slots.closeButton ||
                !!slots.title);
        });
        const maxWidth = useMaxWidth(props.maxSize);
        const { renderClass } = useRenderClass("drawer");
        return {
            renderClass,
            maxWidth,
            close,
            showHeader,
            showCloseButton,
            showTitle,
            isTeleportDisable
        };
    }
});

const _withId$2 = /*#__PURE__*/withScopeId("data-v-655d1e04");

pushScopeId("data-v-655d1e04");
const _hoisted_1$2 = {
  key: 1,
  class: "h-2"
};
popScopeId();

const render$7 = /*#__PURE__*/_withId$2((_ctx, _cache, $props, $setup, $data, $options) => {
  const _component_t_fade = resolveComponent("t-fade");

  return (openBlock(), createBlock(Teleport, {
    to: _ctx.teleportTo,
    disabled: _ctx.isTeleportDisable
  }, [
    (_ctx.backDrop)
      ? (openBlock(), createBlock(_component_t_fade, {
          key: 0,
          show: _ctx.modelValue,
          "allocate-space": false,
          "opacity-class": "opacity-50",
          class: "relative z-30"
        }, {
          default: _withId$2(({className}) => [
            createVNode("div", {
              "data-name": "drawer-backDrop",
              class: [
              // { hidden: !modelValue },
              className,
              _ctx.renderClass('fixed z-20 top-0 bg-gray-900', 'backDrop')
            ],
              onClick: _cache[1] || (_cache[1] = (...args) => (_ctx.close && _ctx.close(...args)))
            }, null, 2 /* CLASS */)
          ]),
          _: 1 /* STABLE */
        }, 8 /* PROPS */, ["show"]))
      : createCommentVNode("v-if", true),
    createVNode("div", {
      "data-name": "drawer-container",
      class: [
        _ctx.renderClass(
          'fixed z-30 top-0 bg-white transform duration-300',
          'container'
        ),
        {
          [_ctx.left
            ? '-translate-x-full -right-full'
            : 'translate-x-full -right-full']: !_ctx.modelValue,
          [_ctx.left ? 'rounded-r-md' : 'rounded-l-md']: _ctx.rounded
        },
        _ctx.left ? 'left-0' : 'right-0',
        _ctx.maxWidth
      ]
    }, [
      (_ctx.showHeader)
        ? (openBlock(), createBlock("div", {
            key: 0,
            "data-name": "drawer-header",
            class: [
          { 'flex-row-reverse': _ctx.left },
          _ctx.renderClass(
            'px-4 h-12 rounded-inherit  py-4 leading-none flex justify-between items-center font-medium text-sm select-none',
            'header'
          )
        ]
          }, [
            createVNode("div", null, [
              (_ctx.showTitle)
                ? (openBlock(), createBlock(resolveDynamicComponent(_ctx.titleTag), {
                    key: 0,
                    class: _ctx.renderClass('', 'title'),
                    "data-name": "drawer-title"
                  }, {
                    default: _withId$2(() => [
                      createTextVNode(toDisplayString(_ctx.title), 1 /* TEXT */)
                    ]),
                    _: 1 /* STABLE */
                  }, 8 /* PROPS */, ["class"]))
                : renderSlot(_ctx.$slots, "title", { key: 1 })
            ]),
            (_ctx.showCloseButton)
              ? (openBlock(), createBlock("div", {
                  key: 0,
                  "data-name": "drawer-close",
                  onClick: _cache[2] || (_cache[2] = (...args) => (_ctx.close && _ctx.close(...args))),
                  class: 
            _ctx.renderClass('text-2xl hover:text-gray-600 cursor-pointer', 'close')
          
                }, " × ", 2 /* CLASS */))
              : renderSlot(_ctx.$slots, "closeButton", {
                  key: 1,
                  onClick: _ctx.close
                })
          ], 2 /* CLASS */))
        : (openBlock(), createBlock("div", _hoisted_1$2)),
      createVNode("div", {
        "data-name": "drawer-contentContainer",
        class: [
          _ctx.renderClass(
            'overflow-y-auto scrollbar-sm p-4 max-h-screen bottom-sheet-content-container drawer-max-height',
            'contentContainer'
          ),
          { 'drawer-height': _ctx.showHeader, 'w-screen': _ctx.full }
        ]
      }, [
        renderSlot(_ctx.$slots, "default")
      ], 2 /* CLASS */),
      createVNode("div", {
        class: [{ [_ctx.left ? 'rounded-br-md' : 'rounded-bl-lg']: _ctx.rounded }, "bg-white h-4 w-full"]
      }, null, 2 /* CLASS */)
    ], 2 /* CLASS */)
  ], 8 /* PROPS */, ["to", "disabled"]))
});

script$7.render = render$7;
script$7.__scopeId = "data-v-655d1e04";
script$7.__file = "src/components/tailwind/drawer/TDrawer.vue";

const useIsScrolling = (onMount = false, element = ref(null)) => {
    const result = ref({});
    const scrollDestroyed = ref(0);
    const handleScroll = (e) => {
        result.value = e;
    };
    const initiateScroll = () => {
        console.log("scroll event initiate", element);
        if (element.value) {
            element.value.addEventListener("scroll", handleScroll);
        }
        else
            document.addEventListener("scroll", handleScroll);
    };
    const destroyScroll = () => {
        console.log("scroll event destroyed", element);
        if (element.value) {
            element.value.removeEventListener("scroll", handleScroll);
        }
        else
            document.removeEventListener("scroll", handleScroll);
    };
    onMounted(() => {
        if (onMount)
            initiateScroll();
    });
    onUnmounted(() => {
        destroyScroll();
        scrollDestroyed.value++;
    });
    return {
        result,
        destroyScroll,
        scrollDestroyed,
        initiateScroll,
        element,
    };
};

var visibilityOverflow;
(function (visibilityOverflow) {
    visibilityOverflow["right"] = "right";
    visibilityOverflow["left"] = "left";
    visibilityOverflow["top"] = "top";
    visibilityOverflow["bottom"] = "bottom";
})(visibilityOverflow || (visibilityOverflow = {}));
let isScrolling = null;
let scrollDestroyed = null;
let destroyScroll = null;
let observersCount = 0;
const useIsVisible = (element = ref(null), parentElement = ref(null)) => {
    observersCount++;
    const isOpen = ref(false);
    const placement = ref(null);
    if (isScrolling === null) {
        const scrollInstance = useIsScrolling();
        isScrolling = scrollInstance.result;
        scrollInstance.initiateScroll();
        destroyScroll = scrollInstance.destroyScroll;
        scrollDestroyed = scrollInstance.scrollDestroyed;
    }
    const handlePlacement = () => {
        if (!isOpen.value)
            return;
        const childBounding = element.value.getBoundingClientRect();
        const parentBounding = parentElement.value.getBoundingClientRect();
        console.log({
            childBounding,
            parentBounding,
        });
        const windowHeight = window.innerHeight || document.documentElement.clientHeight;
        const placementTemporaryValue = [];
        const childWidth = childBounding.width;
        const childHeight = childBounding.height;
        if (parentBounding.top > childHeight) {
            placementTemporaryValue.push(visibilityOverflow.top);
        }
        if (parentBounding.right > childWidth) {
            placementTemporaryValue.push(visibilityOverflow.right);
        }
        if (parentBounding.left > childWidth) {
            placementTemporaryValue.push(visibilityOverflow.left);
        }
        if (windowHeight - parentBounding.bottom > childHeight) {
            placementTemporaryValue.push(visibilityOverflow.bottom);
        }
        if (placementTemporaryValue?.length) {
            placement.value = placementTemporaryValue;
        }
        else {
            placement.value = [
                visibilityOverflow.bottom,
                visibilityOverflow.left,
                visibilityOverflow.right,
                visibilityOverflow.top,
            ];
        }
        console.log(placement.value);
    };
    watch(isScrolling, (resultValue) => {
        console.log("is scrolling");
        handlePlacement();
    });
    onUnmounted(() => {
        observersCount--;
        if (observersCount === 0) {
            destroyScroll();
            isScrolling = null;
        }
    });
    watch(scrollDestroyed, () => {
        observersCount = 0;
        isScrolling = null;
    });
    return {
        element,
        placement,
        parentElement,
        handlePlacement,
        isOpen,
    };
};

const useDelayHandler = (type, animationDelay, isOpened, isClosed) => {
    const getAnimationDelay = computed(() => {
        if (type === delayType.both ||
            (type === delayType.open && isOpened.value) ||
            (type === delayType.close && isClosed.value)) {
            return `delay-${animationDelay}`;
        }
        return "";
    });
    return {
        getAnimationDelay
    };
};

const useClickOutside = (elementRef = ref(null)) => {
    const clickedOutside = ref(false);
    const eventHandler = function (event) {
        const isClickInside = elementRef.value.contains(event.target);
        console.log("click event trigger isClickInside=> ", isClickInside);
        if (!isClickInside) {
            clickedOutside.value = true;
            return;
        }
        clickedOutside.value = false;
    };
    const registerEvent = () => {
        setTimeout(() => {
            console.log("registered click outside event");
            document.addEventListener("click", eventHandler);
        }, 0);
    };
    const unRegisterEvent = () => {
        setTimeout(() => {
            console.log("unregistered click outside event");
            document.removeEventListener("click", eventHandler);
            clickedOutside.value = false;
        }, 0);
    };
    onUnmounted(() => {
        document.removeEventListener("click", eventHandler);
    });
    return {
        elementRef,
        clickedOutside,
        registerEvent,
        unRegisterEvent,
    };
};

const component = (propName) => "t-dropdown-" + propName;
var script$8 = defineComponent({
    props: {
        variant: {
            type: String,
            default: () => inject(component("variant"), variants.white),
            validator: (propValue) => {
                return !!variants[propValue];
            },
        },
        modelValue: {
            type: String,
        },
        divide: {
            type: Boolean,
            default: () => inject(component("divide"), true),
        },
        item: {
            type: Object,
            default: () => ({ label: undefined, value: undefined }),
        },
        outline: {
            type: Boolean,
            default: () => inject(component("outline"), true),
            required: false,
        },
        placeholder: {
            type: String,
            default: () => inject(component("placeholder"), ""),
            required: false,
        },
        rounded: {
            type: Boolean,
            default: () => inject(component("rounded"), false),
            required: false,
        },
        hover: {
            type: Boolean,
            default: () => inject(component("hover"), false),
            required: false,
        },
        top: {
            type: Boolean,
            default: () => inject(component("top"), false),
            required: false,
        },
        items: {
            default: [],
            type: Array,
        },
        opened: {
            type: Boolean,
            default: () => inject(component("opened"), false),
            required: false,
        },
        searchKey: {
            type: String,
            default: "",
        },
        labelField: {
            type: String,
            default: () => inject(component("labelField"), "label"),
        },
        valueField: {
            type: String,
            default: () => inject(component("valueField"), "value"),
        },
        disabled: {
            type: Boolean,
            default: () => inject(component("disabled"), false),
        },
        toggleByHeader: {
            type: Boolean,
            default: () => inject(component("toggleByHeader"), true),
        },
        parentColorClasses: {
            type: String,
            default: () => inject(component("parentColorClasses"), ""),
        },
        itemsColorClasses: {
            type: String,
            default: () => inject(component("itemsColorClasses"), ""),
        },
        animationDuration: {
            type: String,
            default: () => inject(component("animationDuration"), "200"),
        },
        animationDelay: {
            type: String,
            default: () => inject(component("animationDelay"), "0"),
        },
        animationDelayType: {
            type: String,
            default: () => inject(component("animationDelayType"), delayType.both),
            validator: (propValue) => {
                return !!delayType[propValue];
            },
        },
    },
    components: { TTriangle },
    setup(props, { emit, slots }) {
        const baseClass = computed(() => `bg-${props.variant === variants.white
            ? `${props.variant} text-dark bg-white border border-gray-200`
            : `${props.variant} text-white`}  transition ${props.disabled ? "opacity-50" : "hover:opacity-80"}`);
        const outlineClass = computed(() => ` border hover:shadow ${props.disabled
            ? "bg-gray-100"
            : `border-${props.variant}-50 shadow-sm hover:bg-${props.variant}-50`}`);
        const childClass = `bg-${props.variant}-50 hover:bg-${props.variant}-50 hover:opacity-60 focus:border-${props.variant} transition`;
        const state = reactive({
            selected: null,
            opened: props.opened,
            disabled: false,
        });
        const { items, opened, disabled } = toRefs(props);
        // initiate refs
        const dropdownRef = ref(null);
        const dropdownParentRef = ref(null);
        const containerRef = computed(function () {
            return !props.toggleByHeader ? dropdownParentRef : dropdownRef;
        });
        const isOpened = computed(() => {
            return state.opened;
        });
        const isClosed = computed(() => {
            return !isOpened.value;
        });
        const isClosedRounded = computed(() => {
            return isClosed.value && props.rounded;
        });
        const isOpenedRounded = computed(() => {
            return isOpened.value && props.rounded;
        });
        // handle animation delay based on type
        const { getAnimationDelay } = useDelayHandler(props.animationDelayType, props.animationDelay, isOpened, isClosed);
        function updateSelectedValue(item) {
            state.selected = item.value;
            emit("update:modelValue", item.value);
            emit("update:item", item);
        }
        // init clickoutside
        const { clickedOutside, registerEvent, unRegisterEvent } = useClickOutside(containerRef.value);
        // init dropdown visibility
        const { placement, handlePlacement, isOpen: isVisibleWatch } = useIsVisible(dropdownRef, dropdownParentRef);
        // handle dropdown visibility
        function hasPlacementPosition(position) {
            return placement.value?.includes(position);
        }
        const isOverflowed = computed(() => {
            if (props.top) {
                if (hasPlacementPosition(visibilityOverflow.top))
                    return false;
                else {
                    if (hasPlacementPosition(visibilityOverflow.bottom)) {
                        return true;
                    }
                    else
                        return false;
                }
            }
            else {
                if (hasPlacementPosition(visibilityOverflow.bottom))
                    return false;
                else {
                    if (hasPlacementPosition(visibilityOverflow.top)) {
                        return true;
                    }
                    else
                        return false;
                }
            }
        });
        // handler parent rounded class
        const parentRoundedClass = computed(() => {
            //       'rounded-full': isClosedRounded,
            // 'rounded-md': isOpenedRounded,
            // 'rounded-b-none': isOpened && !isOverflowed,
            // 'rounded-t-none': isOpened && isOverflowed,
            if (isOpened.value) {
                if (!isOverflowed.value) {
                    if (props.top) {
                        if (props.rounded) {
                            return "rounded-b-md";
                        }
                        return "rounded-b-sm";
                    }
                    else {
                        if (props.rounded) {
                            return "rounded-t-md";
                        }
                        return "rounded-t-sm";
                    }
                }
                else {
                    if (props.top) {
                        if (props.rounded) {
                            return "rounded-t-md";
                        }
                        return "rounded-t-sm";
                    }
                    else {
                        if (props.rounded) {
                            return "rounded-b-md";
                        }
                        return "rounded-b-sm";
                    }
                }
            }
            else {
                if (props.rounded) {
                    return "rounded-md";
                }
                else {
                    return "rounded-sm";
                }
            }
        });
        // handle child wrapper rounded classes
        const roundedClass = computed(() => {
            if (!isOverflowed.value) {
                if (props.top) {
                    if (props.rounded) {
                        return "rounded-t-md";
                    }
                    return "rounded-t-sm";
                }
                else {
                    if (props.rounded) {
                        return "rounded-b-md";
                    }
                    return "rounded-b-sm";
                }
            }
            else {
                if (props.top) {
                    if (props.rounded) {
                        return "rounded-b-md";
                    }
                    return "rounded-b-sm";
                }
                else {
                    if (props.rounded) {
                        return "rounded-t-md";
                    }
                    return "rounded-t-sm";
                }
            }
            // 'rounded-b-sm': !top && !rounded && !isOverflowed,
            //     'rounded-b-md': !top && rounded && !isOverflowed,
            //     'rounded-t-md': top && rounded && !isOverflowed,
            //     'rounded-b-none': !top && rounded && isOverflowed,
            //     'rounded-t-md': !top && rounded && isOverflowed,
            //     'rounded-t-sm': !top && !rounded && isOverflowed,
            //     'rounded-t-sm': top && !rounded && !isOverflowed,
        });
        const handleVerticalTraslate = computed(() => {
            if (!isOverflowed.value) {
                if (props.top) {
                    return "-translate-y-full top-0";
                }
                return "";
            }
            else {
                if (!props.top) {
                    return "-translate-y-full top-0";
                }
                return "";
            }
        });
        const handleBorderType = computed(() => {
            // isOverflowed ? 'border-b-0' : 'border-t-0'
            if (!isOverflowed.value) {
                if (props.top)
                    return "border-b-0";
                return "border-t-0";
            }
            else {
                if (props.top)
                    return "border-t-0";
                return "border-b-0";
            }
        });
        // initialize dropdown items
        const itemFactory = computed(() => {
            if (!items.value || items.value.length === 0)
                return [];
            const newItems = [];
            items.value.forEach((item) => {
                if (typeof item === "string") {
                    newItems.push({
                        label: item,
                        value: item,
                    });
                }
                else {
                    newItems.push({
                        label: item[props.labelField],
                        value: item[props.valueField],
                    });
                }
            });
            if (props.searchKey) {
                return newItems.filter((i) => i.label.toLowerCase().includes(props.searchKey.toLowerCase()));
            }
            return newItems;
        });
        const selectedItem = computed(() => {
            return (itemFactory.value.find((e) => e.value === state.selected) || {
                label: false,
            });
        });
        const getModelValue = computed(() => props.item.value !== undefined ? props.item.value : props.modelValue);
        watch(getModelValue, (value) => {
            if (value !== state.selected)
                state.selected = value;
        }, { immediate: true });
        const handleEmitOpened = async () => {
            emit("update:opened", isVisibleWatch.value);
            await nextTick();
            handlePlacement();
        };
        // handle open and close state of dropdown
        async function triggerMenu(value = null) {
            // handle disabled
            if (state.disabled)
                return;
            if (value !== state.opened) {
                isVisibleWatch.value = state.opened = value;
                await handleEmitOpened();
            }
            else if (value === null) {
                isVisibleWatch.value = state.opened = !state.opened;
                await handleEmitOpened();
            }
        }
        // handle disabled state
        watch(disabled, (value) => {
            if (value)
                triggerMenu(false);
            state.disabled = value;
        });
        function selectItem(item) {
            triggerMenu(false);
            updateSelectedValue(item);
        }
        // handle clickoutside
        const onEscape = (e) => {
            if (e.key === "Esc" || e.key === "Escape") {
                triggerMenu(false);
            }
        };
        useKeyDown(onEscape);
        watch(clickedOutside, (value) => {
            triggerMenu(false);
        });
        function hoverTriggerMenu(value) {
            if (props.hover) {
                triggerMenu(value);
            }
        }
        watch(opened, (value) => {
            if (value) {
                triggerMenu(true);
            }
            else {
                triggerMenu(false);
            }
        });
        watch(toRefs(state).opened, (value) => {
            if (value) {
                registerEvent();
            }
            else {
                unRegisterEvent();
            }
        });
        // handle arrow direction
        const arrowDirection = computed(function () {
            if (props.top) {
                if (state.opened) {
                    if (isOverflowed.value) {
                        return arrowDirections["arrow-up"];
                    }
                    return arrowDirections["arrow-down"];
                }
                else {
                    return arrowDirections["arrow-up"];
                }
            }
            else {
                if (state.opened) {
                    if (isOverflowed.value) {
                        return arrowDirections["arrow-down"];
                    }
                    return arrowDirections["arrow-up"];
                }
                return arrowDirections["arrow-down"];
            }
        });
        const { renderClass } = useRenderClass("dropdown");
        return {
            hasHeaderSlot: !!slots.header,
            hasItemSlot: !!slots.item,
            hasLabelSlot: !!slots.label,
            hasActivatorSlot: !!slots.activator,
            parentClass: props.parentColorClasses || props.outline ? outlineClass : baseClass,
            childClass: props.itemsColorClasses || childClass,
            roundedClass,
            parentRoundedClass,
            handleVerticalTraslate,
            handleBorderType,
            isOpened,
            isClosed,
            isClosedRounded,
            isOpenedRounded,
            getItems: itemFactory,
            hasItem: computed(() => !!itemFactory.value.length),
            triggerMenu,
            hoverTriggerMenu,
            selectItem,
            selectedItem,
            state,
            dropdownRef,
            dropdownParentRef,
            isOverflowed,
            placement,
            arrowDirection,
            getAnimationDelay,
            renderClass,
        };
    },
});

const _hoisted_1$3 = /*#__PURE__*/createVNode("br", null, null, -1 /* HOISTED */);
const _hoisted_2$1 = {
  key: 0,
  ref: "dropdownParentRef"
};

function render$8(_ctx, _cache, $props, $setup, $data, $options) {
  const _component_TTriangle = resolveComponent("TTriangle");

  return (openBlock(), createBlock(Fragment, null, [
    createTextVNode(" isOverflowed: " + toDisplayString(_ctx.isOverflowed) + " roundedClass: " + toDisplayString(_ctx.roundedClass) + " ", 1 /* TEXT */),
    _hoisted_1$3,
    createVNode("div", {
      class: "relative",
      onMouseenter: _cache[2] || (_cache[2] = $event => (_ctx.hoverTriggerMenu(true))),
      onMouseleave: _cache[3] || (_cache[3] = $event => (_ctx.hoverTriggerMenu(false)))
    }, [
      createCommentVNode(" parent section "),
      createCommentVNode(" header slot  "),
      (_ctx.hasHeaderSlot)
        ? (openBlock(), createBlock("div", _hoisted_2$1, [
            renderSlot(_ctx.$slots, "header", mergeProps({
              selectedItem: _ctx.selectedItem,
              label: _ctx.selectedItem.label,
              value: _ctx.selectedItem.value,
              selectedText: _ctx.selectedItem.label || _ctx.placeholder,
              triggerMenu: _ctx.triggerMenu
            }, _ctx.$attrs))
          ], 512 /* NEED_PATCH */))
        : (openBlock(), createBlock(Fragment, { key: 1 }, [
            createCommentVNode(" default dropdown header & activator slot"),
            createVNode("div", {
              ref: "dropdownParentRef",
              "data-name": "dropdown-parent",
              class: [
          _ctx.renderClass(
            `cursor-pointer w-64 h-10 flex items-center justify-center ${_ctx.parentRoundedClass} ${_ctx.parentClass}`,
            'parent'
          ),
        ],
              onClick: _cache[1] || (_cache[1] = $event => (_ctx.triggerMenu(true)))
            }, [
              (_ctx.hasActivatorSlot)
                ? renderSlot(_ctx.$slots, "activator", {
                    key: 0,
                    selectedItem: _ctx.selectedItem,
                    label: _ctx.selectedItem.label,
                    value: _ctx.selectedItem.value,
                    selectedText: _ctx.selectedItem.label || _ctx.placeholder
                  })
                : (openBlock(), createBlock("div", {
                    key: 1,
                    "data-name": "dropdown-parentWrapper",
                    class: [
              _ctx.renderClass(
                'flex flex-row justify-center items-center w-full',
                'parentWrapper'
              ),
            ]
                  }, [
                    createVNode("span", {
                      "data-name": "dropdown-parentWrapperText",
                      class: [
                _ctx.renderClass(
                  'mr-4 ml-2 overflow-ellipsis overflow-hidden h-full',
                  'parentWrapperText'
                ),
              ]
                    }, toDisplayString(_ctx.selectedItem.label || _ctx.placeholder), 3 /* TEXT, CLASS */),
                    createVNode(_component_TTriangle, {
                      class: [_ctx.renderClass('mr-auto ml-4', 'parentWrapperTriangle')],
                      "data-name": "dropdown-parentWrapperTriangle",
                      direction: _ctx.arrowDirection,
                      variant: ''
                    }, null, 8 /* PROPS */, ["class", "direction"])
                  ], 2 /* CLASS */))
            ], 2 /* CLASS */)
          ], 64 /* STABLE_FRAGMENT */)),
      createCommentVNode(" items "),
      createCommentVNode(" slot for prepend items & item slot "),
      createVNode("div", {
        ref: "dropdownRef",
        class: [[
        _ctx.renderClass(
          `${
            _ctx.variant === 'white'
              ? 'border border-gray-200 ' + _ctx.handleBorderType
              : ''
          } ${_ctx.roundedClass}
        duration-${_ctx.animationDuration}
        ${_ctx.getAnimationDelay}
        transform
        ${_ctx.handleVerticalTraslate}`,
          'children',
          {
            'opacity-0 -translate-y-1/2 z-0 scale-y-0': _ctx.isClosed,
            'z-30': !_ctx.hover,
            'z-40': _ctx.hover,
            'divide-y': _ctx.divide,
          }
        ),
      ], "transform overflow-hidden ease-in-out cursor-pointer transition w-64 absolute bg-white"],
        "data-name": "dropdown-children"
      }, [
        createVNode("div", {
          class: [
          _ctx.renderClass(
            'overflow-y-auto scrollbar-sm max-h-48',
            'childrenScrollbar'
          ),
        ],
          "data-name": "dropdown-childrenScrollbar"
        }, [
          renderSlot(_ctx.$slots, "prepend", { hasItem: _ctx.hasItem }),
          (openBlock(true), createBlock(Fragment, null, renderList(_ctx.getItems, (item, index) => {
            return (openBlock(), createBlock(Fragment, { key: index }, [
              (_ctx.hasItemSlot)
                ? renderSlot(_ctx.$slots, "item", {
                    key: 0,
                    originalItem: _ctx.items[index],
                    item: item,
                    index: index
                  })
                : (openBlock(), createBlock("div", {
                    key: 1,
                    class: ["py-2 overflow-ellipsis overflow-hidden", [
                _ctx.renderClass(
                  'py-2 overflow-ellipsis overflow-hidden ' + _ctx.childClass,
                  'childrenItem',
                  {
                    'bg-gray-100': _ctx.selectedItem.value === item.value,
                  }
                ),
                ,
              ]],
                    "data-name": "dropdown-childrenItem",
                    onClick: $event => (_ctx.selectItem(item))
                  }, [
                    (_ctx.hasLabelSlot)
                      ? renderSlot(_ctx.$slots, "label", {
                          key: 0,
                          item: item,
                          originalItem: _ctx.items[index],
                          index: index
                        })
                      : (openBlock(), createBlock(Fragment, { key: 1 }, [
                          createTextVNode(toDisplayString(item.label), 1 /* TEXT */)
                        ], 64 /* STABLE_FRAGMENT */))
                  ], 10 /* CLASS, PROPS */, ["onClick"]))
            ], 64 /* STABLE_FRAGMENT */))
          }), 128 /* KEYED_FRAGMENT */))
        ], 2 /* CLASS */)
      ], 2 /* CLASS */)
    ], 32 /* HYDRATE_EVENTS */)
  ], 64 /* STABLE_FRAGMENT */))
}

script$8.render = render$8;
script$8.__file = "src/components/tailwind/dropdown/TDropdown.vue";

var script$9 = defineComponent({
    name: "TIcon",
    props: {
        name: {
            type: String,
            default: ""
        }
    },
    setup() {
        const { renderClass } = useRenderClass("icon");
        return { renderClass };
    }
});

function render$9(_ctx, _cache, $props, $setup, $data, $options) {
  return (_ctx.name)
    ? (openBlock(), createBlock("i", {
        key: 0,
        class: _ctx.renderClass('material-icons', 'container')
      }, toDisplayString(_ctx.name), 3 /* TEXT, CLASS */))
    : createCommentVNode("v-if", true)
}

script$9.render = render$9;
script$9.__file = "src/components/tailwind/icon/TIcon.vue";

var SkeletonTypes;
(function (SkeletonTypes) {
    SkeletonTypes["AVATAR_LIST"] = "avatar-list";
    SkeletonTypes["CARD"] = "card";
    SkeletonTypes["ONE_LINE"] = "one-line";
    SkeletonTypes["THREE_LINE"] = "three-line";
    SkeletonTypes["IMAGE"] = "image";
    SkeletonTypes["CUSTOM"] = "custom";
})(SkeletonTypes || (SkeletonTypes = {}));
var LoadingTypes;
(function (LoadingTypes) {
    LoadingTypes["default"] = "default";
    LoadingTypes["spinner"] = "spinner";
})(LoadingTypes || (LoadingTypes = {}));

var script$a = defineComponent({
    name: "TLoading",
    inheritAttrs: false,
    props: {
        size: {
            type: String,
            default: () => inject("t-loading-size", "sm"),
            validator: (propValue) => {
                return !!size[propValue];
            }
        },
        variant: {
            type: String,
            default: () => inject("t-loading-variant", "primary"),
            validator: (propValue) => {
                return !!variants[propValue];
            }
        },
        colorClass: {
            type: String,
            default: () => inject("t-loading-colorClass", "")
        },
        type: {
            type: String,
            default: () => inject("t-loading-type", "default"),
            validator: (propValue) => {
                return !!LoadingTypes[propValue];
            }
        }
    },
    setup(props) {
        const withClass = computed(() => {
            switch (props.size) {
                case size.xs:
                    return props.type === LoadingTypes.default ? "w-1 h-1" : "w-3 h-3";
                case size.sm:
                    return props.type === LoadingTypes.default ? "w-2 h-2" : "w-6 h-6";
                case size.md:
                    return props.type === LoadingTypes.default ? "w-4 h-4" : "w-8 h-8";
                case size.lg:
                    return props.type === LoadingTypes.default ? "w-6 h-6" : "w-10 h-10";
                case size.full:
                    return props.type === LoadingTypes.default ? "w-8 h-8" : "w-12 h-12";
            }
            return "";
        });
        const getBgVariant = computed(() => {
            if (props.colorClass) {
                return props.colorClass;
            }
            return `bg-${props.variant}`;
        });
        const getBorderVariant = computed(() => {
            if (props.colorClass) {
                return props.colorClass;
            }
            return `border-${props.variant}`;
        });
        const { renderClass } = useRenderClass("loading");
        return {
            withClass,
            renderClass,
            LoadingTypes,
            getBgVariant,
            getBorderVariant
        };
    }
});

function render$a(_ctx, _cache, $props, $setup, $data, $options) {
  return (openBlock(), createBlock("div", {
    "data-name": "loading-container",
    class: _ctx.renderClass('flex justify-center', 'container')
  }, [
    (_ctx.type === _ctx.LoadingTypes.spinner)
      ? (openBlock(), createBlock("div", mergeProps({ key: 0 }, _ctx.$attrs, {
          class: _ctx.renderClass(`${_ctx.withClass} relative`, 'spinnerContainer')
        }), [
          createVNode("div", {
            class: 
            _ctx.renderClass(
              `${_ctx.getBorderVariant} absolute top-0 left-0 z-0 rounded-full h-full w-full opacity-60 border-2`,
              'spinnerCircle'
            )
          
          }, null, 2 /* CLASS */),
          createVNode("div", {
            class: 
            _ctx.renderClass(
              `${_ctx.getBorderVariant} absolute top-0 left-0 h-full w-full  z-10 rounded-full border-gray-50 border-t-2 animate-spin`,
              'spinnerSpin'
            )
          
          }, null, 2 /* CLASS */)
        ], 16 /* FULL_PROPS */))
      : (openBlock(), createBlock(Fragment, { key: 1 }, [
          createVNode("div", mergeProps({ "data-name": "loading-item" }, _ctx.$attrs, {
            class: 
          _ctx.renderClass(
            `rounded-full t-loader ${_ctx.getBgVariant} ${_ctx.withClass}`,
            'item'
          )
        
          }), null, 16 /* FULL_PROPS */),
          createVNode("div", mergeProps({ "data-name": "loading-item" }, _ctx.$attrs, {
            class: 
          _ctx.renderClass(
            `rounded-full t-loader-middle mx-1 ${_ctx.getBgVariant} ${_ctx.withClass}`,
            'item'
          )
        
          }), null, 16 /* FULL_PROPS */),
          createVNode("div", mergeProps({ "data-name": "loading-item" }, _ctx.$attrs, {
            class: 
          _ctx.renderClass(
            `rounded-full t-loader ${_ctx.getBgVariant} ${_ctx.withClass}`,
            'item'
          )
        
          }), null, 16 /* FULL_PROPS */)
        ], 64 /* STABLE_FRAGMENT */))
  ], 2 /* CLASS */))
}

script$a.render = render$a;
script$a.__file = "src/components/tailwind/loading/TLoading.vue";

var script$b = defineComponent({
    props: {
        placement: {
            type: String,
            default: "right",
            validator: (value) => ["right", "left"].indexOf(value) !== -1,
        },
        disabled: {
            type: Boolean,
            default: false,
            required: false,
        },
        full: {
            required: false,
            default: false,
            type: Boolean,
        },
        hover: {
            type: Boolean,
            default: false,
            required: false,
        },
        animate: {
            type: Boolean,
            default: false,
            required: false,
        },
    },
    setup(props) {
        const open = ref(false);
        // is menu open
        const isOpen = computed(() => {
            return open.value && !props.disabled;
        });
        // handle escape key
        const onEscape = (e) => {
            if (e.key === "Esc" || e.key === "Escape") {
                open.value = false;
            }
        };
        useKeyDown(onEscape);
        // handle clickoutside
        const { clickedOutside, elementRef: menuRef, registerEvent, unRegisterEvent, } = useClickOutside();
        watch(clickedOutside, (value) => {
            console.log("watch clickoutside", value);
            if (value) {
                open.value = false;
            }
        });
        watchEffect(() => {
            if (open.value) {
                registerEvent();
            }
            else {
                unRegisterEvent();
            }
        });
        const openClose = (value = null) => {
            if (!props.disabled) {
                open.value = value !== null ? value : !open.value;
            }
        };
        const animatedOpened = computed(() => {
            return props.animate && isOpen.value;
        });
        const animatedClosed = computed(() => {
            return props.animate && !isOpen.value;
        });
        const notAnimatedOpened = computed(() => {
            return !props.animate && isOpen.value;
        });
        return {
            menuRef,
            openClose,
            isOpen,
            animatedOpened,
            animatedClosed,
            notAnimatedOpened
        };
    },
});

function render$b(_ctx, _cache, $props, $setup, $data, $options) {
  return (openBlock(), createBlock("div", {
    class: "relative",
    onMouseenter: _cache[2] || (_cache[2] = $event => (_ctx.hover && _ctx.openClose(true))),
    onMouseleave: _cache[3] || (_cache[3] = $event => (_ctx.hover && _ctx.openClose(false)))
  }, [
    createVNode("div", {
      class: " relative flex items-center focus:outline-none min-w-full ",
      onClick: _cache[1] || (_cache[1] = (...args) => (_ctx.openClose && _ctx.openClose(...args)))
    }, [
      renderSlot(_ctx.$slots, "button", { isOpen: _ctx.isOpen })
    ]),
    createCommentVNode("dropdown menu"),
    createVNode(Transition, {
      name: !_ctx.animate && 'fade',
      mode: "out-in"
    }, {
      default: withCtx(() => [
        (_ctx.animate || _ctx.notAnimatedOpened)
          ? (openBlock(), createBlock("div", {
              key: 0,
              ref: "menuRef",
              class: ["absolute shadow-lg border rounded rounded-t-none py-1 px-2 text-sm bg-white z-30 transition transform origin-top-right ", [
          {
            'right-0': _ctx.placement === 'right',
            'left-0': _ctx.placement !== 'right',
            'w-full': _ctx.full,
            'z-30': !_ctx.hover,
            'z-40': _ctx.hover,
            'scale-0 opacity-0': _ctx.animatedClosed,
            'scale-100 opacity-1': _ctx.animatedOpened,
          },
        ]]
            }, [
              renderSlot(_ctx.$slots, "content")
            ], 2 /* CLASS */))
          : createCommentVNode("v-if", true)
      ]),
      _: 1 /* STABLE */
    }, 8 /* PROPS */, ["name"])
  ], 32 /* HYDRATE_EVENTS */))
}

script$b.render = render$b;
script$b.__file = "src/components/tailwind/menu/TMenu.vue";

var script$c = defineComponent({
    name: "TModal",
    components: { TFade },
    emits: {
        "update:modelValue"(value) {
            return typeof value === "number" || typeof value === "boolean";
        }
    },
    props: {
        modelValue: {
            type: [Number, Boolean],
            default: 0
        },
        title: {
            type: String,
            default: ""
        },
        titleTag: {
            type: String,
            default: () => inject("t-modal-titleTag", "h4")
        },
        teleportTo: {
            type: String,
            default: () => inject("t-modal-teleportTo", undefined)
        },
        hasCloseButton: {
            type: Boolean,
            default: () => inject("t-modal-hasCloseButton", true)
        },
        maxSize: {
            type: String,
            default: () => inject("t-modal-maxSize", "lg"),
            validator: (propValue) => {
                return !!size[propValue];
            }
        },
        closeCallback: {
            type: Function,
            default: () => {
                return () => true;
            }
        },
        full: {
            type: Boolean,
            default: () => inject("t-modal-full", false)
        },
        eager: {
            type: Boolean,
            default: () => inject("t-modal-eager", false)
        },
        backDrop: {
            type: Boolean,
            default: () => inject("t-modal-backDrop", true)
        }
    },
    setup(props, { emit, slots }) {
        const close = () => {
            props.closeCallback() && emit("update:modelValue", false);
        };
        const onEscape = (e) => {
            if (e.key === "Esc" || e.key === "Escape") {
                close();
            }
        };
        useKeyDown(onEscape);
        const isTeleportDisable = computed(() => {
            return props.teleportTo === undefined;
        });
        const showTitle = computed(() => {
            return props.title && !slots.title;
        });
        const showCloseButton = computed(() => {
            return props.hasCloseButton && !slots.closeButton;
        });
        const showHeader = computed(() => {
            return (props.hasCloseButton ||
                props.title ||
                !!slots.closeButton ||
                !!slots.title);
        });
        const maxWidth = useMaxWidth(props.maxSize);
        const { renderClass } = useRenderClass("bottomSheet");
        return {
            maxWidth,
            renderClass,
            close,
            showHeader,
            showCloseButton,
            showTitle,
            isTeleportDisable
        };
    }
});

const _hoisted_1$4 = { key: 0 };

function render$c(_ctx, _cache, $props, $setup, $data, $options) {
  const _component_t_fade = resolveComponent("t-fade");

  return (openBlock(), createBlock(Teleport, {
    to: _ctx.teleportTo,
    disabled: _ctx.isTeleportDisable
  }, [
    createVNode("div", null, [
      (_ctx.backDrop)
        ? (openBlock(), createBlock(_component_t_fade, {
            key: 0,
            show: _ctx.modelValue,
            "allocate-space": false,
            "opacity-class": "opacity-50",
            class: "relative z-30"
          }, {
            default: withCtx(({className}) => [
              createVNode("div", {
                "data-name": "modal-backDrop",
                class: [
                // { hidden: !modelValue },
                className,
                _ctx.renderClass('fixed z-20 top-0 bg-gray-900', 'backDrop')
              ],
                onClick: _cache[1] || (_cache[1] = (...args) => (_ctx.close && _ctx.close(...args)))
              }, null, 2 /* CLASS */)
            ]),
            _: 1 /* STABLE */
          }, 8 /* PROPS */, ["show"]))
        : createCommentVNode("v-if", true),
      createVNode(_component_t_fade, {
        duration: 300,
        show: _ctx.modelValue,
        "allocate-space": false,
        class: "relative z-30"
      }, {
        default: withCtx(({className,delayedShow}) => [
          createVNode("div", {
            "data-name": "modal-container",
            class: [
              _ctx.renderClass(
                _ctx.maxWidth +
                  ' fixed z-30  w-max rounded  scrollbar-sm max-h-full overflow-y-auto top-1/2 right-1/2 translate-x-1/2 -translate-y-1/2 transform  bg-white',
                'container'
              ),

              { [className]: !delayedShow }
            ]
          }, [
            createVNode("div", null, [
              (_ctx.eager || delayedShow)
                ? withDirectives((openBlock(), createBlock("div", _hoisted_1$4, [
                    (_ctx.showHeader)
                      ? (openBlock(), createBlock("div", {
                          key: 0,
                          "data-name": "modal-container",
                          class: 
                    _ctx.renderClass(
                      'px-4 sticky top-0 py-4 leading-none flex justify-between items-center font-medium text-sm bg-gray-100 border-b select-none',
                      'header'
                    )
                  
                        }, [
                          createVNode("div", null, [
                            (_ctx.showTitle)
                              ? (openBlock(), createBlock(resolveDynamicComponent(_ctx.titleTag), {
                                  key: 0,
                                  "data-name": "modal-title",
                                  class: _ctx.renderClass('', 'title')
                                }, {
                                  default: withCtx(() => [
                                    createTextVNode(toDisplayString(_ctx.title), 1 /* TEXT */)
                                  ]),
                                  _: 1 /* STABLE */
                                }, 8 /* PROPS */, ["class"]))
                              : renderSlot(_ctx.$slots, "title", { key: 1 })
                          ]),
                          (_ctx.showCloseButton)
                            ? (openBlock(), createBlock("div", {
                                key: 0,
                                onClick: _cache[2] || (_cache[2] = (...args) => (_ctx.close && _ctx.close(...args))),
                                "data-name": "modal-close",
                                class: 
                      _ctx.renderClass(
                        'text-2xl hover:text-gray-600 cursor-pointer',
                        'close'
                      )
                    
                              }, " × ", 2 /* CLASS */))
                            : renderSlot(_ctx.$slots, "closeButton", {
                                key: 1,
                                onClick: _ctx.close
                              })
                        ], 2 /* CLASS */))
                      : createCommentVNode("v-if", true),
                    createVNode("div", {
                      class: { 'w-screen': _ctx.full }
                    }, [
                      createVNode("div", {
                        "data-name": "modal-contentContainer",
                        class: _ctx.renderClass('p-4', 'contentContainer')
                      }, [
                        renderSlot(_ctx.$slots, "default")
                      ], 2 /* CLASS */)
                    ], 2 /* CLASS */)
                  ], 512 /* NEED_PATCH */)), [
                    [vShow, !_ctx.eager || delayedShow]
                  ])
                : createCommentVNode("v-if", true)
            ])
          ], 2 /* CLASS */)
        ]),
        _: 1 /* STABLE */
      }, 8 /* PROPS */, ["show"])
    ])
  ], 8 /* PROPS */, ["to", "disabled"]))
}

script$c.render = render$c;
script$c.__file = "src/components/tailwind/modal/TModal.vue";

var script$d = defineComponent({
    name: "TNumberPicker",
    components: { TLoading, TButton },
    props: {
        modelValue: {
            type: Number,
            default: 1
        },
        min: {
            type: Number,
            default: () => inject("t-number-picker-min", 1)
        },
        max: {
            type: Number,
            default: () => inject("t-number-picker-max", undefined)
        },
        buttonProps: {
            type: Object,
            default: () => inject("t-number-picker-buttonProps", { variant: "primary" })
        },
        loadingProps: {
            type: Object,
            default: () => inject("t-number-picker-loadingProps", {
                variant: "secondary",
                type: "spinner"
            })
        },
        loading: {
            type: Boolean,
            default: () => inject("t-number-picker-loadingProps", false)
        }
    },
    emits: {
        "update:modelValue"(value) {
            return typeof value === "number";
        }
    },
    setup(props, { emit, slots }) {
        const isPlusDisable = computed(() => {
            return props.max !== undefined && props.max <= props.modelValue;
        });
        const isMinusDisable = computed(() => {
            return props.min >= props.modelValue;
        });
        const plus = () => {
            if (!props.max || props.max >= props.modelValue + 1) {
                emit("update:modelValue", props.modelValue + 1);
            }
        };
        const minus = () => {
            if (props.min <= props.modelValue - 1) {
                emit("update:modelValue", props.modelValue - 1);
            }
        };
        const { renderClass } = useRenderClass("numberPicker");
        return {
            renderClass,
            plus,
            minus,
            isPlusDisable,
            isMinusDisable,
            hasPlusSlot: !!slots.plus,
            hasMinusSlot: !!slots.minus,
            hasTextSlot: !!slots.text,
            hasLoadingSlot: !!slots.loading
        };
    }
});

const _hoisted_1$5 = { class: "flex items-center" };
const _hoisted_2$2 = /*#__PURE__*/createTextVNode(" + ");
const _hoisted_3 = {
  key: 3,
  class: "w-10 text-center"
};
const _hoisted_4 = /*#__PURE__*/createTextVNode(" - ");

function render$d(_ctx, _cache, $props, $setup, $data, $options) {
  const _component_t_button = resolveComponent("t-button");
  const _component_t_loading = resolveComponent("t-loading");

  return (openBlock(), createBlock("div", _hoisted_1$5, [
    (_ctx.hasPlusSlot)
      ? renderSlot(_ctx.$slots, "plus", {
          key: 0,
          disabled: _ctx.isPlusDisable || _ctx.loading,
          loading: _ctx.loading,
          click: _ctx.plus
        })
      : (openBlock(), createBlock(_component_t_button, mergeProps({
          key: 1,
          "data-name": "numberPicker-plus",
          disabled: _ctx.isPlusDisable || _ctx.loading,
          onClick: _ctx.plus,
          class: _ctx.renderClass('w-10', 'plus')
        }, _ctx.buttonProps), {
          default: withCtx(() => [
            _hoisted_2$2
          ]),
          _: 1 /* STABLE */
        }, 16 /* FULL_PROPS */, ["disabled", "onClick", "class"])),
    (_ctx.hasTextSlot)
      ? renderSlot(_ctx.$slots, "text", {
          key: 2,
          value: _ctx.modelValue,
          disabled: _ctx.isMinusDisable || _ctx.loading,
          loading: _ctx.loading
        })
      : (openBlock(), createBlock("div", _hoisted_3, [
          (_ctx.loading)
            ? (openBlock(), createBlock(Fragment, { key: 0 }, [
                renderSlot(_ctx.$slots, "loading"),
                (!_ctx.hasLoadingSlot)
                  ? (openBlock(), createBlock(_component_t_loading, mergeProps({
                      key: 0,
                      "data-name": "numberPicker-loading",
                      class: _ctx.renderClass('number-picker-loading', 'loading')
                    }, _ctx.loadingProps), null, 16 /* FULL_PROPS */, ["class"]))
                  : createCommentVNode("v-if", true)
              ], 64 /* STABLE_FRAGMENT */))
            : (openBlock(), createBlock("span", {
                key: 1,
                "data-name": "numberPicker-text",
                class: _ctx.renderClass('number-picker-text', 'text')
              }, toDisplayString(_ctx.modelValue), 3 /* TEXT, CLASS */))
        ])),
    (_ctx.hasMinusSlot)
      ? renderSlot(_ctx.$slots, "minus", {
          key: 4,
          disabled: _ctx.isMinusDisable || _ctx.loading,
          loading: _ctx.loading,
          click: _ctx.minus
        })
      : (openBlock(), createBlock(_component_t_button, mergeProps({
          key: 5,
          "data-name": "numberPicker-minus",
          disabled: _ctx.isMinusDisable || _ctx.loading,
          onClick: _ctx.minus,
          class: _ctx.renderClass('w-10', 'minus')
        }, _ctx.buttonProps), {
          default: withCtx(() => [
            _hoisted_4
          ]),
          _: 1 /* STABLE */
        }, 16 /* FULL_PROPS */, ["disabled", "onClick", "class"]))
  ]))
}

script$d.render = render$d;
script$d.__file = "src/components/tailwind/numberPicker/TNumberPicker.vue";

/*!
  * vue-router v4.0.4
  * (c) 2021 Eduardo San Martin Morote
  * @license MIT
  */

const hasSymbol = typeof Symbol === 'function' && typeof Symbol.toStringTag === 'symbol';
const PolySymbol = (name) => 
// vr = vue router
hasSymbol
    ? Symbol((process.env.NODE_ENV !== 'production') ? '[vue-router]: ' + name : name)
    : ((process.env.NODE_ENV !== 'production') ? '[vue-router]: ' : '_vr_') + name;
// rvlm = Router View Location Matched
/**
 * RouteRecord being rendered by the closest ancestor Router View. Used for
 * `onBeforeRouteUpdate` and `onBeforeRouteLeave`. rvlm stands for Router View
 * Location Matched
 *
 * @internal
 */
/*#__PURE__*/ PolySymbol((process.env.NODE_ENV !== 'production') ? 'router view location matched' : 'rvlm');
/**
 * Allows overriding the router view depth to control which component in
 * `matched` is rendered. rvd stands for Router View Depth
 *
 * @internal
 */
/*#__PURE__*/ PolySymbol((process.env.NODE_ENV !== 'production') ? 'router view depth' : 'rvd');
/**
 * Allows overriding the router instance returned by `useRouter` in tests. r
 * stands for router
 *
 * @internal
 */
/*#__PURE__*/ PolySymbol((process.env.NODE_ENV !== 'production') ? 'router' : 'r');
/**
 * Allows overriding the current route returned by `useRoute` in tests. rl
 * stands for route location
 *
 * @internal
 */
const routeLocationKey = /*#__PURE__*/ PolySymbol((process.env.NODE_ENV !== 'production') ? 'route location' : 'rl');
/**
 * Allows overriding the current route used by router-view. Internally this is
 * used when the `route` prop is passed.
 *
 * @internal
 */
/*#__PURE__*/ PolySymbol((process.env.NODE_ENV !== 'production') ? 'router view location' : 'rvl');

var NavigationType;
(function (NavigationType) {
    NavigationType["pop"] = "pop";
    NavigationType["push"] = "push";
})(NavigationType || (NavigationType = {}));
var NavigationDirection;
(function (NavigationDirection) {
    NavigationDirection["back"] = "back";
    NavigationDirection["forward"] = "forward";
    NavigationDirection["unknown"] = "";
})(NavigationDirection || (NavigationDirection = {}));

/*#__PURE__*/ PolySymbol((process.env.NODE_ENV !== 'production') ? 'navigation failure' : 'nf');
/**
 * Enumeration with all possible types for navigation failures. Can be passed to
 * {@link isNavigationFailure} to check for specific failures.
 */
var NavigationFailureType;
(function (NavigationFailureType) {
    /**
     * An aborted navigation is a navigation that failed because a navigation
     * guard returned `false` or called `next(false)`
     */
    NavigationFailureType[NavigationFailureType["aborted"] = 4] = "aborted";
    /**
     * A cancelled navigation is a navigation that failed because a more recent
     * navigation finished started (not necessarily finished).
     */
    NavigationFailureType[NavigationFailureType["cancelled"] = 8] = "cancelled";
    /**
     * A duplicated navigation is a navigation that failed because it was
     * initiated while already being at the exact same location.
     */
    NavigationFailureType[NavigationFailureType["duplicated"] = 16] = "duplicated";
})(NavigationFailureType || (NavigationFailureType = {}));
/**
 * Returns the current route location. Equivalent to using `$route` inside
 * templates.
 */
function useRoute() {
    return inject(routeLocationKey);
}

var script$e = defineComponent({
    name: "TPagination",
    props: {
        modelValue: {
            type: Number,
            default: 1
        },
        totalCount: {
            type: Number,
            default: 0
        },
        perPage: {
            type: Number,
            default: () => inject("t-pagination-perPage", 20)
        },
        pageRange: {
            type: Number,
            default: () => inject("t-pagination-pageRange", 2)
        },
        variant: {
            type: String,
            default: () => inject("t-pagination-variant", "primary"),
            validator: (propValue) => {
                return !!variants[propValue];
            }
        },
        colorClass: {
            type: String,
            default: () => inject("t-pagination-colorClass", "")
        },
        nuxt: {
            type: Boolean,
            default: () => inject("t-pagination-nuxt", false)
        },
        vue: {
            type: Boolean,
            default: () => inject("t-pagination-vue", false)
        },
        queryName: {
            type: String,
            default: () => inject("t-pagination-queryName", "page")
        },
        appendQuery: {
            type: Boolean,
            default: () => inject("t-pagination-appendQuery", true)
        },
        formName: {
            type: String,
            default: () => inject("t-pagination-formName", "")
        }
    },
    setup(props, { emit, slots }) {
        const route = useRoute();
        const getModelValue = computed(() => {
            if (props.nuxt || props.vue) {
                if (route.query[props.queryName]) {
                    if (props.formName) {
                        return +route.query[props.formName]?.[props.queryName] || 1;
                    }
                    else {
                        return +route.query[props.queryName];
                    }
                }
                else {
                    return 1;
                }
            }
            return props.modelValue;
        });
        const totalPages = computed(() => {
            return Math.ceil(props.totalCount / props.perPage);
        });
        const rangeStart = computed(() => {
            const start = getModelValue.value - props.pageRange;
            return start > 0 ? start : 1;
        });
        const rangeEnd = computed(() => {
            const end = getModelValue.value + props.pageRange;
            if (end < totalPages.value) {
                return end;
            }
            else {
                return totalPages.value;
            }
        });
        const pages = computed(() => {
            const pages = [];
            for (let i = rangeStart.value; i <= rangeEnd.value; i++) {
                pages.push(i);
            }
            return pages;
        });
        const hasFirst = computed(() => rangeStart.value !== 1);
        const hasLast = computed(() => rangeEnd.value < totalPages.value);
        const hasPrev = computed(() => getModelValue.value > 1);
        const hasNext = computed(() => getModelValue.value < totalPages.value);
        const nextPage = computed(() => getModelValue.value + 1);
        const prevPage = computed(() => getModelValue.value - 1);
        const changePage = page => {
            if (page > 0 && page <= totalPages.value) {
                emit("update:modelValue", page);
            }
        };
        const getColorClass = computed(() => {
            if (props.colorClass) {
                return props.colorClass;
            }
            return `bg-${props.variant}`;
        });
        const is = computed(() => {
            if (props.nuxt) {
                return "nuxt-link";
            }
            else if (props.vue) {
                return "router-link";
            }
            return "a";
        });
        const dynamicBinding = computed(() => page => {
            if (props.nuxt || props.vue) {
                const append = props.appendQuery ? route.query : {};
                const pageQuery = props.formName
                    ? { [props.formName]: { [props.queryName]: page } }
                    : { [props.queryName]: page };
                return {
                    to: {
                        query: {
                            ...append,
                            ...pageQuery
                        }
                    }
                };
            }
            return { href: "#" };
        });
        const { renderClass } = useRenderClass("pagination");
        return {
            hasPrevSlot: !!slots.prev,
            hasNextSlot: !!slots.next,
            hasItemSlot: !!slots.item,
            hasPageSlot: !!slots.page,
            getModelValue,
            is,
            dynamicBinding,
            eventPrevent: props.nuxt || props.vue ? null : "click",
            getColorClass,
            renderClass,
            pages,
            changePage,
            totalPages,
            hasPrev,
            hasNext,
            nextPage,
            prevPage,
            hasFirst,
            hasLast
        };
    }
});

const _hoisted_1$6 = { class: "w-full overflow-x-auto" };
const _hoisted_2$3 = /*#__PURE__*/createVNode("path", {
  "stroke-linecap": "round",
  "stroke-linejoin": "round",
  "stroke-width": "2",
  d: "M9 5l7 7-7 7"
}, null, -1 /* HOISTED */);
const _hoisted_3$1 = /*#__PURE__*/createVNode("path", {
  "stroke-linecap": "round",
  "stroke-linejoin": "round",
  "stroke-width": "2",
  d: "M15 19l-7-7 7-7"
}, null, -1 /* HOISTED */);

function render$e(_ctx, _cache, $props, $setup, $data, $options) {
  return (openBlock(), createBlock("div", _hoisted_1$6, [
    createVNode("section", {
      "data-name": "pagination-container",
      class: 
        _ctx.renderClass(
          'flex justify-between bg-white py-3 text-gray-700',
          'container'
        )
      
    }, [
      createVNode("ul", {
        "data-name": "pagination-ul",
        class: _ctx.renderClass('flex items-center mx-auto', 'ul')
      }, [
        (_ctx.hasPrev)
          ? (openBlock(), createBlock("li", {
              key: 0,
              "data-name": "pagination-li",
              class: _ctx.renderClass('px-0.5 sm:px-3', 'li')
            }, [
              createVNode("a", {
                "data-name": "pagination-anchor",
                class: _ctx.renderClass('', 'anchor'),
                href: "#",
                onClick: _cache[1] || (_cache[1] = withModifiers($event => (_ctx.changePage(_ctx.prevPage)), ["prevent"]))
              }, [
                createVNode("span", {
                  "data-name": "pagination-itemContainer",
                  class: 
                _ctx.renderClass(
                  'flex items-center justify-center rounded-full hover:opacity-80  sm:h-10 sm:w-10 h-8 w-8',
                  'itemContainer'
                )
              
                }, [
                  createVNode("span", {
                    "data-name": "pagination-iconContainer",
                    class: _ctx.renderClass('', 'iconContainer')
                  }, [
                    (_ctx.hasPrevSlot)
                      ? renderSlot(_ctx.$slots, "prev", { key: 0 })
                      : (openBlock(), createBlock("svg", {
                          key: 1,
                          "data-name": "pagination-icon",
                          class: _ctx.renderClass('w-4 h-4 sm: h-5 sm:w-5', 'icon'),
                          xmlns: "http://www.w3.org/2000/svg",
                          fill: "none",
                          viewBox: "0 0 24 24",
                          stroke: "currentColor"
                        }, [
                          _hoisted_2$3
                        ], 2 /* CLASS */))
                  ], 2 /* CLASS */)
                ], 2 /* CLASS */)
              ], 2 /* CLASS */)
            ], 2 /* CLASS */))
          : createCommentVNode("v-if", true),
        (_ctx.hasFirst)
          ? (openBlock(), createBlock("li", {
              key: 1,
              "data-name": "pagination-li",
              class: _ctx.renderClass('px-0.5 sm:px-3', 'li')
            }, [
              createVNode("a", {
                "data-name": "pagination-anchor",
                class: _ctx.renderClass('', 'anchor'),
                href: "#",
                onClick: _cache[2] || (_cache[2] = withModifiers($event => (_ctx.changePage(1)), ["prevent"]))
              }, [
                (_ctx.hasItemSlot)
                  ? renderSlot(_ctx.$slots, "item", {
                      key: 0,
                      value: 1
                    })
                  : (openBlock(), createBlock("span", {
                      key: 1,
                      "data-name": "pagination-itemContainer",
                      class: 
                  _ctx.renderClass(
                    'flex items-center justify-center rounded-full hover:opacity-80 sm:h-10 sm:w-10 h-8 w-8',
                    'itemContainer'
                  )
                
                    }, [
                      (_ctx.hasPageSlot)
                        ? renderSlot(_ctx.$slots, "page", {
                            key: 0,
                            value: 1
                          })
                        : (openBlock(), createBlock("span", {
                            key: 1,
                            "data-name": "pagination-page",
                            class: _ctx.renderClass('', 'page')
                          }, " 1 ", 2 /* CLASS */))
                    ], 2 /* CLASS */))
              ], 2 /* CLASS */)
            ], 2 /* CLASS */))
          : createCommentVNode("v-if", true),
        (_ctx.hasFirst)
          ? (openBlock(), createBlock("li", {
              key: 2,
              "data-name": "pagination-li",
              class: _ctx.renderClass('px-0.5 sm:px-3', 'li')
            }, " ... ", 2 /* CLASS */))
          : createCommentVNode("v-if", true),
        (openBlock(true), createBlock(Fragment, null, renderList(_ctx.pages, (page, index) => {
          return (openBlock(), createBlock("li", {
            "data-name": "pagination-li",
            class: _ctx.renderClass('px-0.5 sm:px-3', 'li'),
            key: `page-${index}`
          }, [
            (openBlock(), createBlock(resolveDynamicComponent(_ctx.is), mergeProps({ "data-name": "pagination-anchor" }, _ctx.dynamicBinding(page), {
              class: _ctx.renderClass('cursor-pointer', 'anchor'),
              [toHandlerKey(_ctx.eventPrevent)]: withModifiers($event => (_ctx.changePage(page)), ["prevent"])
            }), {
              default: withCtx(() => [
                createCommentVNode("            v-bind=\"dynamicBind\""),
                createCommentVNode("            href=\"#\""),
                (_ctx.hasItemSlot)
                  ? renderSlot(_ctx.$slots, "item", {
                      key: 0,
                      value: page,
                      activeValue: _ctx.getModelValue
                    })
                  : (openBlock(), createBlock("span", {
                      key: 1,
                      "data-name": "pagination-itemContainer",
                      class: 
                  _ctx.renderClass(
                    'flex items-center justify-center rounded-full hover:opacity-80  sm:h-10 sm:w-10 h-8 w-8',
                    'itemContainer',
                    { [`${_ctx.getColorClass} text-white`]: _ctx.getModelValue === page }
                  )
                
                    }, [
                      (_ctx.hasPageSlot)
                        ? renderSlot(_ctx.$slots, "page", {
                            key: 0,
                            value: page,
                            activeValue: _ctx.getModelValue
                          })
                        : (openBlock(), createBlock("span", {
                            key: 1,
                            "data-name": "pagination-page",
                            class: _ctx.renderClass('', 'page')
                          }, toDisplayString(page), 3 /* TEXT, CLASS */))
                    ], 2 /* CLASS */))
              ]),
              _: 2 /* DYNAMIC */
            }, 1040 /* FULL_PROPS, DYNAMIC_SLOTS */, ["class"]))
          ], 2 /* CLASS */))
        }), 128 /* KEYED_FRAGMENT */)),
        (_ctx.hasLast)
          ? (openBlock(), createBlock("li", {
              key: 3,
              "data-name": "pagination-li",
              class: _ctx.renderClass('px-0.5 sm:px-3', 'li')
            }, " ... ", 2 /* CLASS */))
          : createCommentVNode("v-if", true),
        (_ctx.hasLast)
          ? (openBlock(), createBlock("li", {
              key: 4,
              "data-name": "pagination-li",
              class: _ctx.renderClass('px-0.5 sm:px-3', 'li')
            }, [
              createVNode("a", {
                "data-name": "pagination-anchor",
                class: _ctx.renderClass('', 'anchor'),
                href: "#",
                onClick: _cache[3] || (_cache[3] = withModifiers($event => (_ctx.changePage(_ctx.totalPages)), ["prevent"]))
              }, [
                (_ctx.hasItemSlot)
                  ? renderSlot(_ctx.$slots, "item", {
                      key: 0,
                      value: _ctx.totalPages
                    })
                  : (openBlock(), createBlock("span", {
                      key: 1,
                      "data-name": "pagination-itemContainer",
                      class: 
                  _ctx.renderClass(
                    'flex items-center justify-center rounded-full hover:opacity-80  sm:h-10 sm:w-10 h-8 w-8',
                    'itemContainer'
                  )
                
                    }, [
                      (_ctx.hasPageSlot)
                        ? renderSlot(_ctx.$slots, "page", {
                            key: 0,
                            value: _ctx.totalPages
                          })
                        : (openBlock(), createBlock("span", {
                            key: 1,
                            "data-name": "pagination-page",
                            class: _ctx.renderClass('', 'page')
                          }, toDisplayString(_ctx.totalPages), 3 /* TEXT, CLASS */))
                    ], 2 /* CLASS */))
              ], 2 /* CLASS */)
            ], 2 /* CLASS */))
          : createCommentVNode("v-if", true),
        (_ctx.hasNext)
          ? (openBlock(), createBlock("li", {
              key: 5,
              "data-name": "pagination-li",
              class: _ctx.renderClass('px-0.5 sm:px-3', 'li')
            }, [
              createVNode("a", {
                "data-name": "pagination-anchor",
                class: _ctx.renderClass('', 'anchor'),
                href: "#",
                onClick: _cache[4] || (_cache[4] = withModifiers($event => (_ctx.changePage(_ctx.nextPage)), ["prevent"]))
              }, [
                createVNode("span", {
                  "data-name": "pagination-itemContainer",
                  class: 
                _ctx.renderClass(
                  'flex items-center justify-center rounded-full hover:opacity-80  sm:h-10 sm:w-10 h-8 w-8',
                  'itemContainer'
                )
              
                }, [
                  createVNode("span", {
                    "data-name": "pagination-iconContainer",
                    class: _ctx.renderClass('', 'iconContainer')
                  }, [
                    (_ctx.hasNextSlot)
                      ? renderSlot(_ctx.$slots, "next", { key: 0 })
                      : (openBlock(), createBlock("svg", {
                          key: 1,
                          "data-name": "pagination-icon",
                          class: _ctx.renderClass('w-4 h-4 sm: h-5 sm:w-5', 'icon'),
                          xmlns: "http://www.w3.org/2000/svg",
                          fill: "none",
                          viewBox: "0 0 24 24",
                          stroke: "currentColor"
                        }, [
                          _hoisted_3$1
                        ], 2 /* CLASS */))
                  ], 2 /* CLASS */)
                ], 2 /* CLASS */)
              ], 2 /* CLASS */)
            ], 2 /* CLASS */))
          : createCommentVNode("v-if", true)
      ], 2 /* CLASS */)
    ], 2 /* CLASS */)
  ]))
}

script$e.render = render$e;
script$e.__file = "src/components/tailwind/pagination/TPagination.vue";

var script$f = defineComponent({
    name: "TProgressBar",
    props: {
        value: {
            type: Number,
            default: 0
        },
        max: {
            type: Number,
            default: () => inject("t-progress-bar-max", 100)
        },
        showPercent: {
            type: Boolean,
            default: () => inject("t-progress-bar-showPercent", false)
        },
        variant: {
            type: String,
            default: () => inject("t-progress-bar-variant", "primary"),
            validator: (propValue) => {
                // eslint-disable-next-line @typescript-eslint/ban-ts-ignore
                // @ts-ignore
                return !!variants[propValue];
            }
        }
    },
    setup(props) {
        const percent = computed(() => (props.value * 100) / props.max);
        const { renderClass } = useRenderClass("progressBar");
        return { percent, renderClass };
    }
});

const _hoisted_1$7 = { class: "w-full ltr" };

function render$f(_ctx, _cache, $props, $setup, $data, $options) {
  return (openBlock(), createBlock("div", _hoisted_1$7, [
    createVNode("div", mergeProps({
      "data-name": "progressBar-container",
      class: 
        _ctx.renderClass('shadow w-full bg-gray-200 rounded-full', 'container')
      
    }, _ctx.$attrs), [
      createVNode("div", {
        "data-name": "progressBar-progress",
        class: [
          `bg-${_ctx.variant}`,
          { 'text-white': _ctx.variant !== 'white' },
          _ctx.renderClass(
            'rounded-inherit text-xs leading-none py-1 text-center transition',
            'progress'
          )
        ],
        style: { width: `${_ctx.percent}%` }
      }, [
        (_ctx.showPercent)
          ? (openBlock(), createBlock(Fragment, { key: 0 }, [
              createTextVNode(toDisplayString(Math.floor(_ctx.percent)) + "%", 1 /* TEXT */)
            ], 64 /* STABLE_FRAGMENT */))
          : createCommentVNode("v-if", true),
        renderSlot(_ctx.$slots, "default", {
          percent: Math.floor(_ctx.percent)
        })
      ], 6 /* CLASS, STYLE */)
    ], 16 /* FULL_PROPS */)
  ]))
}

script$f.render = render$f;
script$f.__file = "src/components/tailwind/progress/TProgressBar.vue";

var script$g = defineComponent({
    name: "TRadio",
    inheritAttrs: false,
    props: {
        modelValue: [String, Number, Boolean, Object, Array],
        value: [String, Number, Boolean, Object, Array],
        disabled: Boolean,
        label: { type: String, default: "" },
        variant: {
            type: String,
            default: () => inject("t-radio-variant", "primary"),
            validator: (propValue) => {
                // eslint-disable-next-line @typescript-eslint/ban-ts-ignore
                // @ts-ignore
                return !!variants[propValue];
            }
        },
        activeClass: {
            type: String,
            default: () => inject("t-radio-activeClass", "")
        },
        inActiveClass: {
            type: String,
            default: () => inject("t-radio-inActiveClass", "")
        },
        hideInput: {
            type: Boolean,
            default: () => false
        }
    },
    emits: ["update:modelValue"],
    setup(props, { emit }) {
        const newValue = ref(props.modelValue);
        const computedValue = computed({
            get: () => {
                return newValue.value;
            },
            set: val => {
                newValue.value = val;
                emit("update:modelValue", val);
            }
        });
        const isChecked = computed(() => {
            return ((typeof props.value === "object" &&
                JSON.stringify(props.value) === JSON.stringify(props.modelValue)) ||
                props.value === props.modelValue);
        });
        watch(() => props.modelValue, val => {
            newValue.value = val;
        });
        const { renderClass } = useRenderClass("radio");
        return { computedValue, isChecked, renderClass };
    }
});

function render$g(_ctx, _cache, $props, $setup, $data, $options) {
  return (openBlock(), createBlock("label", {
    "data-name": "radio-container",
    class: [
      _ctx.$attrs.class,
      _ctx.renderClass('flex items-center', 'container'),
      {
        'cursor-pointer': !_ctx.disabled,
        [_ctx.activeClass]: _ctx.isChecked,
        [_ctx.inActiveClass]: !_ctx.isChecked
      }
    ]
  }, [
    createVNode("span", {
      "data-name": "radio-inputContainer",
      class: [
        _ctx.renderClass(
          'rounded-full flex flex-shrink-0 justify-center items-center',
          'inputContainer'
        ),
        {
          [`border-${_ctx.variant}`]: _ctx.isChecked && !_ctx.hideInput,
          'bg-white border-gray-400': !_ctx.isChecked && !_ctx.hideInput
        },
        _ctx.hideInput ? 'w-0 h-0' : 'w-6 h-6 border-2 mr-2'
      ]
    }, [
      withDirectives(createVNode("input", mergeProps({
        class: [[{ 'cursor-pointer': !_ctx.disabled }, `checked:bg-${_ctx.variant}`], "opacity-0 absolute"],
        type: "radio"
      }, _ctx.$attrs, {
        disabled: _ctx.disabled,
        value: _ctx.value,
        "onUpdate:modelValue": _cache[1] || (_cache[1] = $event => (_ctx.computedValue = $event))
      }), null, 16 /* FULL_PROPS */, ["disabled", "value"]), [
        [vModelRadio, _ctx.computedValue]
      ]),
      createVNode("span", {
        class: ["w-3 h-3 rounded-full", { [`bg-${_ctx.variant}`]: _ctx.isChecked, hidden: _ctx.hideInput }]
      }, null, 2 /* CLASS */)
    ], 2 /* CLASS */),
    (_ctx.label)
      ? (openBlock(), createBlock("span", {
          key: 0,
          "data-name": "radio-label",
          class: [{ 'text-gray-500': _ctx.disabled }, _ctx.renderClass('mr-2', 'label')]
        }, toDisplayString(_ctx.label), 3 /* TEXT, CLASS */))
      : createCommentVNode("v-if", true),
    renderSlot(_ctx.$slots, "label", {
      isChecked: _ctx.isChecked,
      disabled: _ctx.disabled
    })
  ], 2 /* CLASS */))
}

script$g.render = render$g;
script$g.__file = "src/components/tailwind/radio/TRadio.vue";

var script$h = defineComponent({
    props: {
        type: {
            type: String,
            default: () => inject("t-skeleton-type", SkeletonTypes.AVATAR_LIST),
            validator: (value) => {
                return Object.values(SkeletonTypes).includes(value);
            }
        },
        border: {
            type: Boolean,
            default: () => inject("t-skeleton-border", true)
        },
        shadow: {
            type: Boolean,
            default: () => inject("t-skeleton-shadow", true)
        },
        rounded: {
            type: Boolean,
            default: () => inject("t-skeleton-rounded", false)
        }
    },
    setup(props) {
        const { renderClass } = useRenderClass("skeleton");
        const shadowClass = computed(() => (props.shadow ? "shadow" : ""));
        const borderClass = computed(() => props.border ? "border border-gray-200" : "");
        const roundedClass = computed(() => (props.rounded ? "rounded-md" : ""));
        const roundedSmClass = computed(() => (props.rounded ? "rounded-sm" : ""));
        return {
            SkeletonTypes: SkeletonTypes,
            renderClass,
            shadowClass,
            borderClass,
            roundedClass,
            roundedSmClass
        };
    }
});

const _hoisted_1$8 = /*#__PURE__*/createVNode("div", { class: "skeleton-box absolute top-0 right-0 bottom-0 left-0 transform -translate-x-full" }, null, -1 /* HOISTED */);
const _hoisted_2$4 = { class: "flex-1 space-y-4 py-1" };
const _hoisted_3$2 = { class: "space-y-2" };
const _hoisted_4$1 = /*#__PURE__*/createVNode("div", { class: "skeleton-box absolute top-0 right-0 bottom-0 left-0 transform -translate-x-full" }, null, -1 /* HOISTED */);
const _hoisted_5 = /*#__PURE__*/createVNode("div", { class: "skeleton-box absolute top-0 right-0 bottom-0 left-0 transform -translate-x-full" }, null, -1 /* HOISTED */);
const _hoisted_6 = /*#__PURE__*/createVNode("div", { class: "skeleton-box absolute top-0 right-0 bottom-0 left-0 transform -translate-x-full" }, null, -1 /* HOISTED */);
const _hoisted_7 = /*#__PURE__*/createVNode("div", { class: "skeleton-box absolute top-0 right-0 bottom-0 left-0 transform -translate-x-full" }, null, -1 /* HOISTED */);
const _hoisted_8 = /*#__PURE__*/createVNode("div", { class: "skeleton-box absolute top-0 right-0 bottom-0 left-0 transform -translate-x-full" }, null, -1 /* HOISTED */);

function render$h(_ctx, _cache, $props, $setup, $data, $options) {
  return (_ctx.type === _ctx.SkeletonTypes.AVATAR_LIST)
    ? (openBlock(), createBlock("div", mergeProps({
        key: 0,
        "data-name": "skeleton-avatarListContainer"
      }, _ctx.$attrs, {
        class: [
        _ctx.renderClass(
          `p-4 w-full mx-auto cursor-wait ${_ctx.borderClass}  ${_ctx.shadowClass} ${_ctx.roundedClass}`,
          'avatarListContainer'
        )
      ]
      }), [
        createVNode("div", {
          "data-name": "skeleton-avatarListInnerContainer",
          class: 
          _ctx.renderClass(
            'relative overflow-hidden animate-pulse delay-500 flex space-x-reverse space-x-4',
            'avatarListInnerContainer'
          )
        
        }, [
          _hoisted_1$8,
          createVNode("div", {
            "data-name": "skeleton-avatarListCircle",
            class: 
            _ctx.renderClass(
              'rounded-full bg-gray-300 h-12 w-12',
              'avatarListCircle'
            )
          
          }, null, 2 /* CLASS */),
          createVNode("div", _hoisted_2$4, [
            createVNode("div", {
              "data-name": "skeleton-avatarListLine",
              class: 
              _ctx.renderClass('h-4 bg-gray-300 rounded w-3/4', 'avatarListLine')
            
            }, null, 2 /* CLASS */),
            createVNode("div", _hoisted_3$2, [
              createVNode("div", {
                "data-name": "skeleton-avatarListLine",
                class: _ctx.renderClass('h-4 bg-gray-300 rounded', 'avatarListLine')
              }, null, 2 /* CLASS */),
              createVNode("div", {
                "data-name": "skeleton-avatarListLine",
                class: 
                _ctx.renderClass('h-4 bg-gray-300 rounded w-5/6', 'avatarListLine')
              
              }, null, 2 /* CLASS */)
            ])
          ])
        ], 2 /* CLASS */)
      ], 16 /* FULL_PROPS */))
    : (_ctx.type === _ctx.SkeletonTypes.IMAGE)
      ? (openBlock(), createBlock("div", mergeProps({
          key: 1,
          "data-name": "skeleton-imageContainer"
        }, _ctx.$attrs, {
          class: [
        _ctx.renderClass(
          `${_ctx.roundedSmClass} ${_ctx.shadowClass} ${_ctx.borderClass} max-w-xs w-full mx-auto cursor-wait`,
          'imageContainer'
        )
      ]
        }), [
          createVNode("div", {
            "data-name": "skeleton-imageInnerContainer",
            class: 
          _ctx.renderClass(
            'relative overflow-hidden animate-pulse delay-500',
            'imageInnerContainer'
          )
        
          }, [
            _hoisted_4$1,
            createVNode("div", {
              "data-name": "skeleton-image",
              class: 
            _ctx.renderClass(`w-full h-60 bg-gray-300 ${_ctx.roundedSmClass}`, 'image')
          
            }, null, 2 /* CLASS */)
          ], 2 /* CLASS */)
        ], 16 /* FULL_PROPS */))
      : (_ctx.type === _ctx.SkeletonTypes.CARD)
        ? (openBlock(), createBlock("div", mergeProps({
            key: 2,
            "data-name": "skeleton-cardContainer"
          }, _ctx.$attrs, {
            class: 
        _ctx.renderClass(
          `${_ctx.roundedSmClass} ${_ctx.shadowClass} ${_ctx.borderClass} max-w-xs  w-full mx-auto cursor-wait`,
          'cardContainer'
        )
      
          }), [
            createVNode("div", {
              "data-name": "skeleton-cardInnerContainer",
              class: 
          _ctx.renderClass(
            'relative overflow-hidden flex flex-col pb-5 animate-pulse delay-500',
            'cardInnerContainer'
          )
        
            }, [
              _hoisted_5,
              createVNode("div", {
                "data-name": "skeleton-cardImage",
                class: [
            _ctx.renderClass(
              `${_ctx.rounded ? 'rounded-t-sm' : ''} w-full h-60 bg-gray-300 mb-5`,
              'cardImage'
            )
          ]
              }, null, 2 /* CLASS */),
              (_ctx.$slots.footer)
                ? renderSlot(_ctx.$slots, "footer", { key: 0 })
                : (openBlock(), createBlock("div", {
                    key: 1,
                    "data-name": "skeleton-cardLine",
                    class: 
              _ctx.renderClass('h-4 bg-gray-300 rounded w-1/2 mr-6', 'cardLine')
            
                  }, null, 2 /* CLASS */))
            ], 2 /* CLASS */)
          ], 16 /* FULL_PROPS */))
        : (_ctx.type === _ctx.SkeletonTypes.ONE_LINE)
          ? (openBlock(), createBlock("div", mergeProps({
              key: 3,
              "data-name": "skeleton-lineContainer"
            }, _ctx.$attrs, {
              class: 
        _ctx.renderClass(
          `${_ctx.roundedClass} ${_ctx.shadowClass} ${_ctx.borderClass} p-4 w-full mx-auto cursor-wait`,
          'lineContainer'
        )
      
            }), [
              createVNode("div", {
                "data-name": "skeleton-line",
                class: 
          _ctx.renderClass(
            'relative overflow-hidden delay-500 animate-pulse h-4 bg-gray-300 rounded w-full',
            'line'
          )
        
              }, [
                _hoisted_6
              ], 2 /* CLASS */)
            ], 16 /* FULL_PROPS */))
          : (_ctx.type === _ctx.SkeletonTypes.THREE_LINE)
            ? (openBlock(), createBlock("div", mergeProps({ key: 4 }, _ctx.$attrs, {
                "data-name": "skeleton-threeLineContainer",
                class: 
        _ctx.renderClass(
          `${_ctx.roundedClass} ${_ctx.shadowClass} ${_ctx.borderClass} p-4 w-full mx-auto cursor-wait`,
          'threeLineContainer'
        )
      
              }), [
                createVNode("div", {
                  "data-name": "skeleton-threeLineInnerContainer",
                  class: 
          _ctx.renderClass(
            'relative overflow-hidden flex-1 space-y-3 py-1 animate-pulse delay-500',
            'threeLineInnerContainer'
          )
        
                }, [
                  _hoisted_7,
                  createVNode("div", {
                    "data-name": "skeleton-threeLine",
                    class: _ctx.renderClass('h-4 bg-gray-300 rounded w-3/4', 'threeLine')
                  }, null, 2 /* CLASS */),
                  createVNode("div", {
                    "data-name": "skeleton-threeLine",
                    class: _ctx.renderClass('h-4 bg-gray-300 rounded', 'threeLine')
                  }, null, 2 /* CLASS */),
                  createVNode("div", {
                    "data-name": "skeleton-threeLine",
                    class: _ctx.renderClass('h-4 bg-gray-300 rounded w-5/6', 'threeLine')
                  }, null, 2 /* CLASS */)
                ], 2 /* CLASS */)
              ], 16 /* FULL_PROPS */))
            : (_ctx.type === _ctx.SkeletonTypes.CUSTOM)
              ? (openBlock(), createBlock("div", mergeProps({ key: 5 }, _ctx.$attrs, {
                  "data-name": "skeleton-customContainer",
                  class: 
        _ctx.renderClass(
          `${_ctx.roundedClass} ${_ctx.shadowClass} ${_ctx.borderClass} w-full mx-auto cursor-wait`,
          'customContainer'
        )
      
                }), [
                  createVNode("div", {
                    "data-name": "skeleton-custom",
                    class: 
          _ctx.renderClass(
            'relative overflow-hidden animate-pulse delay-500',
            'custom'
          )
        
                  }, [
                    _hoisted_8,
                    renderSlot(_ctx.$slots, "default")
                  ], 2 /* CLASS */)
                ], 16 /* FULL_PROPS */))
              : createCommentVNode("v-if", true)
}

script$h.render = render$h;
script$h.__file = "src/components/tailwind/skeleton/TSkeleton.vue";

var script$i = defineComponent({
    name: "TStepper",
    props: {
        modelValue: { type: [String, Number], default: 0 },
        items: {
            type: Array,
            default: () => []
        },
        label: { type: String, default: () => inject("t-stepper-label", "label") },
        value: { type: String, default: () => inject("t-stepper-value", "value") },
        text: { type: String, default: () => inject("t-stepper-text", "text") },
        variant: {
            type: String,
            default: () => inject("t-stepper-variant", "primary"),
            validator: (propValue) => {
                // eslint-disable-next-line @typescript-eslint/ban-ts-ignore
                // @ts-ignore
                return !!variants[propValue];
            }
        },
        clickable: {
            type: Boolean,
            default: () => inject("t-stepper-clickable", false)
        }
    },
    setup(props, { slots, emit }) {
        const activeIndex = computed(() => {
            const index = props.items.findIndex(item => item[props.value] === props.modelValue);
            if (index != -1) {
                return index;
            }
            else if (typeof props.modelValue === "number") {
                return props.modelValue;
            }
            else {
                return -1;
            }
        });
        // watchEffect(() => {
        //   console.log("activeIndex", activeIndex.value);
        //   console.log("modelValue", props.modelValue);
        // });
        const isActive = computed(() => (index) => {
            return index === activeIndex.value;
        });
        const isComplete = computed(() => (index) => {
            return index < activeIndex.value;
        });
        const onItemClicked = ({ item, index }) => {
            props.clickable &&
                !item.locked &&
                emit("update:modelValue", item[props.value] ?? index);
        };
        const { renderClass } = useRenderClass("bottomSheet");
        return {
            renderClass,
            onItemClicked,
            activeIndex,
            isActive,
            isComplete,
            hasLabelSlot: !!slots.label,
            hasCircleSlot: !!slots.circle,
            hasTextSlot: !!slots.text
        };
    }
});

const _hoisted_1$9 = { class: "flex items-center" };
const _hoisted_2$5 = {
  key: 1,
  class: "mt-4"
};

function render$i(_ctx, _cache, $props, $setup, $data, $options) {
  return (openBlock(), createBlock("div", {
    "data-name": "stepper-container",
    class: _ctx.renderClass('mx-4 p-4', 'container')
  }, [
    createVNode("div", _hoisted_1$9, [
      (openBlock(true), createBlock(Fragment, null, renderList(_ctx.items, (item, index) => {
        return (openBlock(), createBlock(Fragment, {
          key: `stepper-item-${index}`
        }, [
          createVNode("div", {
            "data-name": "stepper-itemContainer",
            class: [
            {
              'cursor-pointer': _ctx.clickable && !item.locked,
              'cursor-not-allowed': item.locked
            },
            _ctx.renderClass(
              'flex items-center text-gray-400 relative',
              'itemContainer'
            )
          ],
            onClick: $event => (_ctx.onItemClicked({ item, index }))
          }, [
            (_ctx.hasCircleSlot)
              ? renderSlot(_ctx.$slots, "circle", mergeProps({
                  key: 0,
                  isActive: _ctx.isActive(index),
                  isComplete: _ctx.isComplete(index)
                }, item, { index: index }))
              : (openBlock(), createBlock("div", {
                  key: 1,
                  class: [
              _ctx.renderClass(
                'flex items-center justify-center rounded-full transition-all duration-500 ease-in-out h-12 w-12 py-3 border-2',
                'circle',
                {
                  'border-gray-400': !_ctx.isActive(index) && !_ctx.isComplete(index)
                }
              ),

              _ctx.renderClass(
                `${_ctx.isActive(index) ? `border-${_ctx.variant} text-${_ctx.variant}` : ''}`,
                'activeCircle'
              ),
              _ctx.renderClass(
                `${
                  _ctx.isComplete(index) ? `border-${_ctx.variant} text-${_ctx.variant}` : ''
                }`,
                'completeCircle'
              )
            ]
                }, [
                  (_ctx.hasLabelSlot)
                    ? renderSlot(_ctx.$slots, "label", mergeProps({
                        key: 0,
                        isActive: _ctx.isActive(index),
                        isComplete: _ctx.isComplete(index)
                      }, item, { index: index }))
                    : (openBlock(), createBlock(Fragment, { key: 1 }, [
                        createTextVNode(toDisplayString(item[_ctx.label] || index + 1), 1 /* TEXT */)
                      ], 64 /* STABLE_FRAGMENT */))
                ], 2 /* CLASS */)),
            (item[_ctx.text])
              ? (openBlock(), createBlock("div", {
                  key: 2,
                  "data-name": "stepper-text",
                  class: 
              _ctx.renderClass(
                'absolute right-1/2 transform translate-x-1/2 text-center mt-16 text-xs text-gray-500',
                'text'
              )
            
                }, [
                  (_ctx.hasTextSlot)
                    ? renderSlot(_ctx.$slots, "text", mergeProps({
                        key: 0,
                        isActive: _ctx.isActive(index),
                        isComplete: _ctx.isComplete(index)
                      }, item, { index: index }))
                    : (openBlock(), createBlock("div", _hoisted_2$5, toDisplayString(item[_ctx.text]), 1 /* TEXT */))
                ], 2 /* CLASS */))
              : createCommentVNode("v-if", true)
          ], 10 /* CLASS, PROPS */, ["onClick"]),
          (index !== _ctx.items.length - 1)
            ? (openBlock(), createBlock("div", {
                key: 0,
                "data-name": "stepper-line",
                class: 
              _ctx.renderClass(
                `${
                  _ctx.isComplete(index + 1) || _ctx.isActive(index + 1)
                    ? `bg-${_ctx.variant}`
                    : 'bg-gray-400'
                } flex-auto h-0.5 transition-all duration-400 ease-in-out`,
                'line'
              )
            
              }, null, 2 /* CLASS */))
            : createCommentVNode("v-if", true)
        ], 64 /* STABLE_FRAGMENT */))
      }), 128 /* KEYED_FRAGMENT */))
    ])
  ], 2 /* CLASS */))
}

script$i.render = render$i;
script$i.__file = "src/components/tailwind/stepper/TStepper.vue";

var script$j = defineComponent({
    props: SwitchAndCheckboxProps(false),
    emits: ["update:modelValue"],
    setup(props, context) {
        onMounted(() => {
            if (Array.isArray(props.modelValue) && props.value === undefined) {
                console.error("TSwitchError: v-model is Array but value is undefined you should pass a value");
            }
        });
        const { isChecked, updateInput } = useSwitchAndCheckbox(props, context);
        const { renderClass } = useRenderClass("switch");
        return { isChecked, updateInput, renderClass };
    }
});

function render$j(_ctx, _cache, $props, $setup, $data, $options) {
  return (openBlock(), createBlock("div", {
    "data-name": "switch-container",
    class: [
      { 'cursor-pointer': !_ctx.disabled },
      _ctx.renderClass('flex justify-between items-center', 'container')
    ],
    onClick: _cache[1] || (_cache[1] = (...args) => (_ctx.updateInput && _ctx.updateInput(...args)))
  }, [
    createVNode("div", {
      "data-name": "switch-pan",
      class: [
        _ctx.renderClass(
          `${
            _ctx.isChecked ? `bg-${_ctx.variant}` : ''
          } w-16 h-8 flex items-center bg-gray-300 rounded-full p-1 duration-300 ease-in-out`,
          'pan'
        )
      ]
    }, [
      createVNode("div", {
        "data-name": "switch-circle",
        class: [
          { '-translate-x-8': _ctx.isChecked },
          _ctx.renderClass(
            'bg-white w-6 h-6 rounded-full shadow-md transform duration-300 ease-in-out',
            'circle'
          )
        ]
      }, null, 2 /* CLASS */)
    ], 2 /* CLASS */),
    createVNode("label", {
      class: [
        { 'text-gray-500': _ctx.disabled, 'cursor-pointer': !_ctx.disabled },
        _ctx.renderClass('mr-2', 'label')
      ]
    }, toDisplayString(_ctx.label), 3 /* TEXT, CLASS */)
  ], 2 /* CLASS */))
}

script$j.render = render$j;
script$j.__file = "src/components/tailwind/switch/TSwitch.vue";

var ScrollDirections;
(function (ScrollDirections) {
    ScrollDirections["left"] = "scrollLeft";
    ScrollDirections["bottom"] = "scrollBottom";
})(ScrollDirections || (ScrollDirections = {}));

const useScrollElement = () => {
    const scrollTo = (element, scrollPixels, duration, direction) => {
        // element[direction] = scrollPixels;
        const scrollPos = element[direction];
        // Get the start timestamp
        const startTime = "now" in window.performance ? performance.now() : new Date().getTime();
        const scroll = timestamp => {
            //Calculate the timeelapsed
            const timeElapsed = timestamp - startTime;
            //Calculate progress
            const progress = Math.min(timeElapsed / duration, 1);
            //Set the scroll direction
            element[direction] = scrollPos + scrollPixels * progress;
            //Check if elapsed time is less then duration then call the requestAnimation, otherwise exit
            if (timeElapsed < duration) {
                //Request for animation
                window.requestAnimationFrame(scroll);
            }
            else {
                return;
            }
        };
        //Call requestAnimationFrame on scroll function first time
        window.requestAnimationFrame(scroll);
    };
    const elementRef = ref(null);
    const scrollLeft = (scrollPixels, duration = 200) => {
        scrollTo(elementRef.value, scrollPixels * -1, duration, ScrollDirections.left);
    };
    const scrollRight = (scrollPixels, duration = 200) => {
        scrollTo(elementRef.value, scrollPixels, duration, ScrollDirections.left);
    };
    const hasHorizontalScrollbar = ref(false);
    onMounted(() => {
        // elementRef.value.addEventListener("resize", e => {
        //   console.log("resize called", e);
        // });
        hasHorizontalScrollbar.value =
            elementRef.value.scrollWidth > elementRef.value.clientWidth;
    });
    return { elementRef, scrollLeft, scrollRight, hasHorizontalScrollbar };
};

const useIntersectElement = (options = { passRef: true }, callbackFunction, elementRef = ref(null), mounted = true) => {
    const isIntersecting = ref(false);
    let observer;
    const observeFunc = () => {
        const callback = (entries, observer) => {
            if (options.passRef == true) {
                isIntersecting.value = entries[0].isIntersecting;
            }
            callbackFunction?.(entries[0], observer);
        };
        observer = new IntersectionObserver(callback, options);
        observer.observe(mounted ? elementRef.value : elementRef);
    };
    if (mounted)
        onMounted(() => {
            observeFunc();
        });
    else
        observeFunc();
    const destroyObserver = () => {
        observer.disconnect();
    };
    if (options.passRef) {
        return { elementRef, isIntersecting, destroyObserver };
    }
    return { elementRef, destroyObserver };
};

var script$k = defineComponent({
    name: "TTabs",
    components: { TIcon: TIcon$1 },
    props: {
        modelValue: { type: [String, Number], default: 0 },
        arrows: {
            type: Boolean,
            default: () => inject("t-tabs-arrows", true)
        },
        variant: {
            type: String,
            default: () => inject("t-tabs-variant", "primary"),
            validator: (propValue) => {
                // eslint-disable-next-line @typescript-eslint/ban-ts-ignore
                // @ts-ignore
                return !!variants[propValue];
            }
        }
    },
    setup(props, { slots, emit }) {
        const state = reactive({
            selectedIndex: 0,
            tabs: [],
            count: 0
        });
        provide("TabsProvider", state);
        const selectTab = (i, tab, e) => {
            e.target.scrollIntoView({
                behavior: "smooth",
                block: "nearest"
            });
            emit("update:modelValue", tab.props.value || i);
        };
        const renderChildren = () => {
            if (slots.default) {
                //@ts-ignore
                state.tabs = slots.default().filter(child => {
                    //@ts-ignore
                    return child.type.name === "TTabItem";
                });
                const selectedIndex = state.tabs.findIndex(item => item?.props?.value === props.modelValue);
                if (selectedIndex !== -1) {
                    state.selectedIndex = selectedIndex;
                }
                else if (typeof props.modelValue === "number") {
                    state.selectedIndex = props.modelValue;
                }
            }
        };
        watchEffect(() => {
            renderChildren();
        });
        const tabsLength = computed(() => state.tabs.length);
        watch(() => tabsLength.value, (value, oldValue) => {
            console.warn("t-tabs : change tabs length is not allowed", `from: ${oldValue} to: ${value}`);
        });
        const { elementRef: navRef, scrollLeft, scrollRight } = useScrollElement();
        const onScrollLeft = () => {
            scrollLeft(navRef.value.clientWidth, 200);
        };
        const onScrollRight = () => {
            scrollRight(navRef.value.clientWidth, 200);
        };
        const { elementRef: startItem, isIntersecting: startIntersecting } = useIntersectElement({
            passRef: true,
            root: navRef.value
        });
        const { elementRef: endItem, isIntersecting: endIntersecting } = useIntersectElement({
            passRef: true,
            root: navRef.value
        });
        const showArrows = computed(() => props.arrows && (!startIntersecting.value || !endIntersecting.value));
        const { renderClass } = useRenderClass("tabs");
        return {
            hasTitleSlot: !!slots.title,
            startIntersecting,
            endIntersecting,
            startItem,
            endItem,
            ...toRefs(state),
            selectTab,
            onScrollLeft,
            onScrollRight,
            showArrows,
            navRef,
            renderClass,
            hasRightArrowSlot: !!slots.arrowRight,
            hasLeftArrowSlot: !!slots.arrowLeft
        };
    }
});

const _hoisted_1$a = {
  ref: "startItem",
  class: "w-1 h-1 px-1"
};
const _hoisted_2$6 = {
  ref: "endItem",
  class: "w-1 h-1 px-1"
};

function render$k(_ctx, _cache, $props, $setup, $data, $options) {
  const _component_t_icon = resolveComponent("t-icon");

  return (openBlock(), createBlock("div", {
    "data-name": "tabs-container",
    class: _ctx.renderClass('flex flex-col items-center space-y-4', 'container')
  }, [
    createVNode("div", {
      "data-name": "tabs-headerContainer",
      class: 
        _ctx.renderClass('flex max-w-full row items-center', 'headerContainer')
      
    }, [
      (_ctx.showArrows)
        ? (openBlock(), createBlock("div", {
            key: 0,
            onClick: _cache[1] || (_cache[1] = (...args) => (_ctx.onScrollRight && _ctx.onScrollRight(...args)))
          }, [
            (_ctx.hasRightArrowSlot)
              ? renderSlot(_ctx.$slots, "arrowRight", {
                  key: 0,
                  disabled: _ctx.endIntersecting
                })
              : (openBlock(), createBlock(_component_t_icon, {
                  key: 1,
                  disabled: _ctx.startIntersecting,
                  name: "keyboard_arrow_right",
                  "data-name": "tabs-arrow",
                  class: _ctx.renderClass('tab-arrow', 'arrow')
                }, null, 8 /* PROPS */, ["disabled", "class"]))
          ]))
        : createCommentVNode("v-if", true),
      createVNode("nav", {
        ref: "navRef",
        "data-name": "tabs-nav",
        class: 
          _ctx.renderClass(
            'flex items-center flex-row max-w-full overflow-x-auto scrollbar-hidden',
            'nav'
          )
        
      }, [
        createVNode("div", _hoisted_1$a, null, 512 /* NEED_PATCH */),
        (_ctx.hasTitleSlot)
          ? (openBlock(true), createBlock(Fragment, { key: 0 }, renderList(_ctx.tabs, (tab, index) => {
              return (openBlock(), createBlock("div", {
                key: `${index}-${tab.props.title}`,
                onClick: $event => (_ctx.selectTab(index, tab, $event))
              }, [
                renderSlot(_ctx.$slots, "title", mergeProps({
                  selected: index === _ctx.selectedIndex,
                  title: tab.props.title
                }, tab.props))
              ], 8 /* PROPS */, ["onClick"]))
            }), 128 /* KEYED_FRAGMENT */))
          : (openBlock(true), createBlock(Fragment, { key: 1 }, renderList(_ctx.tabs, (tab, index) => {
              return (openBlock(), createBlock("button", {
                key: `${index}-${tab.props.title}`,
                onClick: $event => (_ctx.selectTab(index, tab, $event)),
                "data-name": "tabs-header",
                class: [
            _ctx.renderClass(
              `${
                index === _ctx.selectedIndex
                  ? `text-${_ctx.variant} border-b-2 font-medium border-${_ctx.variant}`
                  : ''
              } text-gray-600 min-w-max py-4 px-6 block  md:hover:text-blue-500 focus:outline-none`,
              'header'
            )
          ]
              }, toDisplayString(tab.props.title), 11 /* TEXT, CLASS, PROPS */, ["onClick"]))
            }), 128 /* KEYED_FRAGMENT */)),
        createVNode("div", _hoisted_2$6, null, 512 /* NEED_PATCH */)
      ], 2 /* CLASS */),
      (_ctx.showArrows)
        ? (openBlock(), createBlock("div", {
            key: 1,
            onClick: _cache[2] || (_cache[2] = (...args) => (_ctx.onScrollLeft && _ctx.onScrollLeft(...args)))
          }, [
            (_ctx.hasLeftArrowSlot)
              ? renderSlot(_ctx.$slots, "arrowLeft", {
                  key: 0,
                  disabled: _ctx.endIntersecting
                })
              : (openBlock(), createBlock(_component_t_icon, {
                  key: 1,
                  disabled: _ctx.endIntersecting,
                  name: "keyboard_arrow_left",
                  "data-name": "tabs-arrow",
                  class: _ctx.renderClass('tab-arrow', 'arrow')
                }, null, 8 /* PROPS */, ["disabled", "class"]))
          ]))
        : createCommentVNode("v-if", true)
    ], 2 /* CLASS */),
    createVNode("div", null, [
      renderSlot(_ctx.$slots, "default")
    ])
  ], 2 /* CLASS */))
}

script$k.render = render$k;
script$k.__file = "src/components/tailwind/tab/TTabs.vue";

var script$l = defineComponent({
    name: "TTabItem",
    props: {
        eager: {
            type: Boolean,
            default: false
        }
    },
    setup() {
        const index = ref(0);
        const isActive = ref(false);
        const activeOnce = ref(false);
        const tabs = inject("TabsProvider");
        watch(() => tabs.selectedIndex, value => {
            isActive.value = index.value === value;
        });
        onBeforeMount(() => {
            index.value = tabs.count;
            tabs.count++;
            isActive.value = index.value === tabs.selectedIndex;
        });
        watchEffect(() => {
            if (isActive.value) {
                activeOnce.value = true;
            }
        });
        return { index, isActive, activeOnce };
    }
});

function render$l(_ctx, _cache, $props, $setup, $data, $options) {
  return (openBlock(), createBlock("div", {
    class: { 'h-0 overflow-hidden': !_ctx.isActive }
  }, [
    createVNode("div", {
      class: ["transform transition-all ease-in duration-300", { 'opacity-0': !_ctx.isActive }]
    }, [
      (_ctx.activeOnce || _ctx.eager)
        ? renderSlot(_ctx.$slots, "default", {
            key: 0,
            isActive: _ctx.isActive,
            index: _ctx.index
          })
        : createCommentVNode("v-if", true)
    ], 2 /* CLASS */)
  ], 2 /* CLASS */))
}

script$l.render = render$l;
script$l.__file = "src/components/tailwind/tab/TTabItem.vue";

var index = {
    TAlert: script$1,
    TAccordion: script,
    TBottomSheet: script$2,
    TBreadcrumb: script$3,
    TButton: script$4,
    TCard: script$5,
    TCheckbox: script$6,
    TDrawer: script$7,
    TDropdown: script$8,
    TIcon: script$9,
    TLoading: script$a,
    TMenu: script$b,
    TModal: script$c,
    TNumberPicker: script$d,
    TPagination: script$e,
    TProgressBar: script$f,
    TRadio: script$g,
    TSkeleton: script$h,
    TStepper: script$i,
    TSwitch: script$j,
    TTabs: script$k,
    TTabItem: script$l
};

export default index;
//# sourceMappingURL=tailwind-vue3.esm.js.map
